from . import CS_OP_INVALID, CS_OP_REG, CS_OP_IMM, CS_OP_MEM
# For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT [sysz_const.py]

SYSZ_CC_INVALID = 0
SYSZ_CC_O = 1
SYSZ_CC_H = 2
SYSZ_CC_NLE = 3
SYSZ_CC_L = 4
SYSZ_CC_NHE = 5
SYSZ_CC_LH = 6
SYSZ_CC_NE = 7
SYSZ_CC_E = 8
SYSZ_CC_NLH = 9
SYSZ_CC_HE = 10
SYSZ_CC_NL = 11
SYSZ_CC_LE = 12
SYSZ_CC_NH = 13
SYSZ_CC_NO = 14

SYSZ_OP_INVALID = 0
SYSZ_OP_REG = 1
SYSZ_OP_IMM = 2
SYSZ_OP_MEM = 3
SYSZ_OP_ACREG = 64

SYSZ_REG_INVALID = 0
SYSZ_REG_0 = 1
SYSZ_REG_1 = 2
SYSZ_REG_2 = 3
SYSZ_REG_3 = 4
SYSZ_REG_4 = 5
SYSZ_REG_5 = 6
SYSZ_REG_6 = 7
SYSZ_REG_7 = 8
SYSZ_REG_8 = 9
SYSZ_REG_9 = 10
SYSZ_REG_10 = 11
SYSZ_REG_11 = 12
SYSZ_REG_12 = 13
SYSZ_REG_13 = 14
SYSZ_REG_14 = 15
SYSZ_REG_15 = 16
SYSZ_REG_CC = 17
SYSZ_REG_F0 = 18
SYSZ_REG_F1 = 19
SYSZ_REG_F2 = 20
SYSZ_REG_F3 = 21
SYSZ_REG_F4 = 22
SYSZ_REG_F5 = 23
SYSZ_REG_F6 = 24
SYSZ_REG_F7 = 25
SYSZ_REG_F8 = 26
SYSZ_REG_F9 = 27
SYSZ_REG_F10 = 28
SYSZ_REG_F11 = 29
SYSZ_REG_F12 = 30
SYSZ_REG_F13 = 31
SYSZ_REG_F14 = 32
SYSZ_REG_F15 = 33
SYSZ_REG_R0L = 34
SYSZ_REG_A0 = 35
SYSZ_REG_A1 = 36
SYSZ_REG_A2 = 37
SYSZ_REG_A3 = 38
SYSZ_REG_A4 = 39
SYSZ_REG_A5 = 40
SYSZ_REG_A6 = 41
SYSZ_REG_A7 = 42
SYSZ_REG_A8 = 43
SYSZ_REG_A9 = 44
SYSZ_REG_A10 = 45
SYSZ_REG_A11 = 46
SYSZ_REG_A12 = 47
SYSZ_REG_A13 = 48
SYSZ_REG_A14 = 49
SYSZ_REG_A15 = 50
SYSZ_REG_C0 = 51
SYSZ_REG_C1 = 52
SYSZ_REG_C2 = 53
SYSZ_REG_C3 = 54
SYSZ_REG_C4 = 55
SYSZ_REG_C5 = 56
SYSZ_REG_C6 = 57
SYSZ_REG_C7 = 58
SYSZ_REG_C8 = 59
SYSZ_REG_C9 = 60
SYSZ_REG_C10 = 61
SYSZ_REG_C11 = 62
SYSZ_REG_C12 = 63
SYSZ_REG_C13 = 64
SYSZ_REG_C14 = 65
SYSZ_REG_C15 = 66
SYSZ_REG_V0 = 67
SYSZ_REG_V1 = 68
SYSZ_REG_V2 = 69
SYSZ_REG_V3 = 70
SYSZ_REG_V4 = 71
SYSZ_REG_V5 = 72
SYSZ_REG_V6 = 73
SYSZ_REG_V7 = 74
SYSZ_REG_V8 = 75
SYSZ_REG_V9 = 76
SYSZ_REG_V10 = 77
SYSZ_REG_V11 = 78
SYSZ_REG_V12 = 79
SYSZ_REG_V13 = 80
SYSZ_REG_V14 = 81
SYSZ_REG_V15 = 82
SYSZ_REG_V16 = 83
SYSZ_REG_V17 = 84
SYSZ_REG_V18 = 85
SYSZ_REG_V19 = 86
SYSZ_REG_V20 = 87
SYSZ_REG_V21 = 88
SYSZ_REG_V22 = 89
SYSZ_REG_V23 = 90
SYSZ_REG_V24 = 91
SYSZ_REG_V25 = 92
SYSZ_REG_V26 = 93
SYSZ_REG_V27 = 94
SYSZ_REG_V28 = 95
SYSZ_REG_V29 = 96
SYSZ_REG_V30 = 97
SYSZ_REG_V31 = 98
SYSZ_REG_F16 = 99
SYSZ_REG_F17 = 100
SYSZ_REG_F18 = 101
SYSZ_REG_F19 = 102
SYSZ_REG_F20 = 103
SYSZ_REG_F21 = 104
SYSZ_REG_F22 = 105
SYSZ_REG_F23 = 106
SYSZ_REG_F24 = 107
SYSZ_REG_F25 = 108
SYSZ_REG_F26 = 109
SYSZ_REG_F27 = 110
SYSZ_REG_F28 = 111
SYSZ_REG_F29 = 112
SYSZ_REG_F30 = 113
SYSZ_REG_F31 = 114
SYSZ_REG_F0Q = 115
SYSZ_REG_F4Q = 116
SYSZ_REG_ENDING = 117

SYSZ_INS_INVALID = 0
SYSZ_INS_A = 1
SYSZ_INS_ADB = 2
SYSZ_INS_ADBR = 3
SYSZ_INS_AEB = 4
SYSZ_INS_AEBR = 5
SYSZ_INS_AFI = 6
SYSZ_INS_AG = 7
SYSZ_INS_AGF = 8
SYSZ_INS_AGFI = 9
SYSZ_INS_AGFR = 10
SYSZ_INS_AGHI = 11
SYSZ_INS_AGHIK = 12
SYSZ_INS_AGR = 13
SYSZ_INS_AGRK = 14
SYSZ_INS_AGSI = 15
SYSZ_INS_AH = 16
SYSZ_INS_AHI = 17
SYSZ_INS_AHIK = 18
SYSZ_INS_AHY = 19
SYSZ_INS_AIH = 20
SYSZ_INS_AL = 21
SYSZ_INS_ALC = 22
SYSZ_INS_ALCG = 23
SYSZ_INS_ALCGR = 24
SYSZ_INS_ALCR = 25
SYSZ_INS_ALFI = 26
SYSZ_INS_ALG = 27
SYSZ_INS_ALGF = 28
SYSZ_INS_ALGFI = 29
SYSZ_INS_ALGFR = 30
SYSZ_INS_ALGHSIK = 31
SYSZ_INS_ALGR = 32
SYSZ_INS_ALGRK = 33
SYSZ_INS_ALHSIK = 34
SYSZ_INS_ALR = 35
SYSZ_INS_ALRK = 36
SYSZ_INS_ALY = 37
SYSZ_INS_AR = 38
SYSZ_INS_ARK = 39
SYSZ_INS_ASI = 40
SYSZ_INS_AXBR = 41
SYSZ_INS_AY = 42
SYSZ_INS_BCR = 43
SYSZ_INS_BRC = 44
SYSZ_INS_BRCL = 45
SYSZ_INS_CGIJ = 46
SYSZ_INS_CGRJ = 47
SYSZ_INS_CIJ = 48
SYSZ_INS_CLGIJ = 49
SYSZ_INS_CLGRJ = 50
SYSZ_INS_CLIJ = 51
SYSZ_INS_CLRJ = 52
SYSZ_INS_CRJ = 53
SYSZ_INS_BER = 54
SYSZ_INS_JE = 55
SYSZ_INS_JGE = 56
SYSZ_INS_LOCE = 57
SYSZ_INS_LOCGE = 58
SYSZ_INS_LOCGRE = 59
SYSZ_INS_LOCRE = 60
SYSZ_INS_STOCE = 61
SYSZ_INS_STOCGE = 62
SYSZ_INS_BHR = 63
SYSZ_INS_BHER = 64
SYSZ_INS_JHE = 65
SYSZ_INS_JGHE = 66
SYSZ_INS_LOCHE = 67
SYSZ_INS_LOCGHE = 68
SYSZ_INS_LOCGRHE = 69
SYSZ_INS_LOCRHE = 70
SYSZ_INS_STOCHE = 71
SYSZ_INS_STOCGHE = 72
SYSZ_INS_JH = 73
SYSZ_INS_JGH = 74
SYSZ_INS_LOCH = 75
SYSZ_INS_LOCGH = 76
SYSZ_INS_LOCGRH = 77
SYSZ_INS_LOCRH = 78
SYSZ_INS_STOCH = 79
SYSZ_INS_STOCGH = 80
SYSZ_INS_CGIJNLH = 81
SYSZ_INS_CGRJNLH = 82
SYSZ_INS_CIJNLH = 83
SYSZ_INS_CLGIJNLH = 84
SYSZ_INS_CLGRJNLH = 85
SYSZ_INS_CLIJNLH = 86
SYSZ_INS_CLRJNLH = 87
SYSZ_INS_CRJNLH = 88
SYSZ_INS_CGIJE = 89
SYSZ_INS_CGRJE = 90
SYSZ_INS_CIJE = 91
SYSZ_INS_CLGIJE = 92
SYSZ_INS_CLGRJE = 93
SYSZ_INS_CLIJE = 94
SYSZ_INS_CLRJE = 95
SYSZ_INS_CRJE = 96
SYSZ_INS_CGIJNLE = 97
SYSZ_INS_CGRJNLE = 98
SYSZ_INS_CIJNLE = 99
SYSZ_INS_CLGIJNLE = 100
SYSZ_INS_CLGRJNLE = 101
SYSZ_INS_CLIJNLE = 102
SYSZ_INS_CLRJNLE = 103
SYSZ_INS_CRJNLE = 104
SYSZ_INS_CGIJH = 105
SYSZ_INS_CGRJH = 106
SYSZ_INS_CIJH = 107
SYSZ_INS_CLGIJH = 108
SYSZ_INS_CLGRJH = 109
SYSZ_INS_CLIJH = 110
SYSZ_INS_CLRJH = 111
SYSZ_INS_CRJH = 112
SYSZ_INS_CGIJNL = 113
SYSZ_INS_CGRJNL = 114
SYSZ_INS_CIJNL = 115
SYSZ_INS_CLGIJNL = 116
SYSZ_INS_CLGRJNL = 117
SYSZ_INS_CLIJNL = 118
SYSZ_INS_CLRJNL = 119
SYSZ_INS_CRJNL = 120
SYSZ_INS_CGIJHE = 121
SYSZ_INS_CGRJHE = 122
SYSZ_INS_CIJHE = 123
SYSZ_INS_CLGIJHE = 124
SYSZ_INS_CLGRJHE = 125
SYSZ_INS_CLIJHE = 126
SYSZ_INS_CLRJHE = 127
SYSZ_INS_CRJHE = 128
SYSZ_INS_CGIJNHE = 129
SYSZ_INS_CGRJNHE = 130
SYSZ_INS_CIJNHE = 131
SYSZ_INS_CLGIJNHE = 132
SYSZ_INS_CLGRJNHE = 133
SYSZ_INS_CLIJNHE = 134
SYSZ_INS_CLRJNHE = 135
SYSZ_INS_CRJNHE = 136
SYSZ_INS_CGIJL = 137
SYSZ_INS_CGRJL = 138
SYSZ_INS_CIJL = 139
SYSZ_INS_CLGIJL = 140
SYSZ_INS_CLGRJL = 141
SYSZ_INS_CLIJL = 142
SYSZ_INS_CLRJL = 143
SYSZ_INS_CRJL = 144
SYSZ_INS_CGIJNH = 145
SYSZ_INS_CGRJNH = 146
SYSZ_INS_CIJNH = 147
SYSZ_INS_CLGIJNH = 148
SYSZ_INS_CLGRJNH = 149
SYSZ_INS_CLIJNH = 150
SYSZ_INS_CLRJNH = 151
SYSZ_INS_CRJNH = 152
SYSZ_INS_CGIJLE = 153
SYSZ_INS_CGRJLE = 154
SYSZ_INS_CIJLE = 155
SYSZ_INS_CLGIJLE = 156
SYSZ_INS_CLGRJLE = 157
SYSZ_INS_CLIJLE = 158
SYSZ_INS_CLRJLE = 159
SYSZ_INS_CRJLE = 160
SYSZ_INS_CGIJNE = 161
SYSZ_INS_CGRJNE = 162
SYSZ_INS_CIJNE = 163
SYSZ_INS_CLGIJNE = 164
SYSZ_INS_CLGRJNE = 165
SYSZ_INS_CLIJNE = 166
SYSZ_INS_CLRJNE = 167
SYSZ_INS_CRJNE = 168
SYSZ_INS_CGIJLH = 169
SYSZ_INS_CGRJLH = 170
SYSZ_INS_CIJLH = 171
SYSZ_INS_CLGIJLH = 172
SYSZ_INS_CLGRJLH = 173
SYSZ_INS_CLIJLH = 174
SYSZ_INS_CLRJLH = 175
SYSZ_INS_CRJLH = 176
SYSZ_INS_BLR = 177
SYSZ_INS_BLER = 178
SYSZ_INS_JLE = 179
SYSZ_INS_JGLE = 180
SYSZ_INS_LOCLE = 181
SYSZ_INS_LOCGLE = 182
SYSZ_INS_LOCGRLE = 183
SYSZ_INS_LOCRLE = 184
SYSZ_INS_STOCLE = 185
SYSZ_INS_STOCGLE = 186
SYSZ_INS_BLHR = 187
SYSZ_INS_JLH = 188
SYSZ_INS_JGLH = 189
SYSZ_INS_LOCLH = 190
SYSZ_INS_LOCGLH = 191
SYSZ_INS_LOCGRLH = 192
SYSZ_INS_LOCRLH = 193
SYSZ_INS_STOCLH = 194
SYSZ_INS_STOCGLH = 195
SYSZ_INS_JL = 196
SYSZ_INS_JGL = 197
SYSZ_INS_LOCL = 198
SYSZ_INS_LOCGL = 199
SYSZ_INS_LOCGRL = 200
SYSZ_INS_LOCRL = 201
SYSZ_INS_LOC = 202
SYSZ_INS_LOCG = 203
SYSZ_INS_LOCGR = 204
SYSZ_INS_LOCR = 205
SYSZ_INS_STOCL = 206
SYSZ_INS_STOCGL = 207
SYSZ_INS_BNER = 208
SYSZ_INS_JNE = 209
SYSZ_INS_JGNE = 210
SYSZ_INS_LOCNE = 211
SYSZ_INS_LOCGNE = 212
SYSZ_INS_LOCGRNE = 213
SYSZ_INS_LOCRNE = 214
SYSZ_INS_STOCNE = 215
SYSZ_INS_STOCGNE = 216
SYSZ_INS_BNHR = 217
SYSZ_INS_BNHER = 218
SYSZ_INS_JNHE = 219
SYSZ_INS_JGNHE = 220
SYSZ_INS_LOCNHE = 221
SYSZ_INS_LOCGNHE = 222
SYSZ_INS_LOCGRNHE = 223
SYSZ_INS_LOCRNHE = 224
SYSZ_INS_STOCNHE = 225
SYSZ_INS_STOCGNHE = 226
SYSZ_INS_JNH = 227
SYSZ_INS_JGNH = 228
SYSZ_INS_LOCNH = 229
SYSZ_INS_LOCGNH = 230
SYSZ_INS_LOCGRNH = 231
SYSZ_INS_LOCRNH = 232
SYSZ_INS_STOCNH = 233
SYSZ_INS_STOCGNH = 234
SYSZ_INS_BNLR = 235
SYSZ_INS_BNLER = 236
SYSZ_INS_JNLE = 237
SYSZ_INS_JGNLE = 238
SYSZ_INS_LOCNLE = 239
SYSZ_INS_LOCGNLE = 240
SYSZ_INS_LOCGRNLE = 241
SYSZ_INS_LOCRNLE = 242
SYSZ_INS_STOCNLE = 243
SYSZ_INS_STOCGNLE = 244
SYSZ_INS_BNLHR = 245
SYSZ_INS_JNLH = 246
SYSZ_INS_JGNLH = 247
SYSZ_INS_LOCNLH = 248
SYSZ_INS_LOCGNLH = 249
SYSZ_INS_LOCGRNLH = 250
SYSZ_INS_LOCRNLH = 251
SYSZ_INS_STOCNLH = 252
SYSZ_INS_STOCGNLH = 253
SYSZ_INS_JNL = 254
SYSZ_INS_JGNL = 255
SYSZ_INS_LOCNL = 256
SYSZ_INS_LOCGNL = 257
SYSZ_INS_LOCGRNL = 258
SYSZ_INS_LOCRNL = 259
SYSZ_INS_STOCNL = 260
SYSZ_INS_STOCGNL = 261
SYSZ_INS_BNOR = 262
SYSZ_INS_JNO = 263
SYSZ_INS_JGNO = 264
SYSZ_INS_LOCNO = 265
SYSZ_INS_LOCGNO = 266
SYSZ_INS_LOCGRNO = 267
SYSZ_INS_LOCRNO = 268
SYSZ_INS_STOCNO = 269
SYSZ_INS_STOCGNO = 270
SYSZ_INS_BOR = 271
SYSZ_INS_JO = 272
SYSZ_INS_JGO = 273
SYSZ_INS_LOCO = 274
SYSZ_INS_LOCGO = 275
SYSZ_INS_LOCGRO = 276
SYSZ_INS_LOCRO = 277
SYSZ_INS_STOCO = 278
SYSZ_INS_STOCGO = 279
SYSZ_INS_STOC = 280
SYSZ_INS_STOCG = 281
SYSZ_INS_BASR = 282
SYSZ_INS_BR = 283
SYSZ_INS_BRAS = 284
SYSZ_INS_BRASL = 285
SYSZ_INS_J = 286
SYSZ_INS_JG = 287
SYSZ_INS_BRCT = 288
SYSZ_INS_BRCTG = 289
SYSZ_INS_C = 290
SYSZ_INS_CDB = 291
SYSZ_INS_CDBR = 292
SYSZ_INS_CDFBR = 293
SYSZ_INS_CDGBR = 294
SYSZ_INS_CDLFBR = 295
SYSZ_INS_CDLGBR = 296
SYSZ_INS_CEB = 297
SYSZ_INS_CEBR = 298
SYSZ_INS_CEFBR = 299
SYSZ_INS_CEGBR = 300
SYSZ_INS_CELFBR = 301
SYSZ_INS_CELGBR = 302
SYSZ_INS_CFDBR = 303
SYSZ_INS_CFEBR = 304
SYSZ_INS_CFI = 305
SYSZ_INS_CFXBR = 306
SYSZ_INS_CG = 307
SYSZ_INS_CGDBR = 308
SYSZ_INS_CGEBR = 309
SYSZ_INS_CGF = 310
SYSZ_INS_CGFI = 311
SYSZ_INS_CGFR = 312
SYSZ_INS_CGFRL = 313
SYSZ_INS_CGH = 314
SYSZ_INS_CGHI = 315
SYSZ_INS_CGHRL = 316
SYSZ_INS_CGHSI = 317
SYSZ_INS_CGR = 318
SYSZ_INS_CGRL = 319
SYSZ_INS_CGXBR = 320
SYSZ_INS_CH = 321
SYSZ_INS_CHF = 322
SYSZ_INS_CHHSI = 323
SYSZ_INS_CHI = 324
SYSZ_INS_CHRL = 325
SYSZ_INS_CHSI = 326
SYSZ_INS_CHY = 327
SYSZ_INS_CIH = 328
SYSZ_INS_CL = 329
SYSZ_INS_CLC = 330
SYSZ_INS_CLFDBR = 331
SYSZ_INS_CLFEBR = 332
SYSZ_INS_CLFHSI = 333
SYSZ_INS_CLFI = 334
SYSZ_INS_CLFXBR = 335
SYSZ_INS_CLG = 336
SYSZ_INS_CLGDBR = 337
SYSZ_INS_CLGEBR = 338
SYSZ_INS_CLGF = 339
SYSZ_INS_CLGFI = 340
SYSZ_INS_CLGFR = 341
SYSZ_INS_CLGFRL = 342
SYSZ_INS_CLGHRL = 343
SYSZ_INS_CLGHSI = 344
SYSZ_INS_CLGR = 345
SYSZ_INS_CLGRL = 346
SYSZ_INS_CLGXBR = 347
SYSZ_INS_CLHF = 348
SYSZ_INS_CLHHSI = 349
SYSZ_INS_CLHRL = 350
SYSZ_INS_CLI = 351
SYSZ_INS_CLIH = 352
SYSZ_INS_CLIY = 353
SYSZ_INS_CLR = 354
SYSZ_INS_CLRL = 355
SYSZ_INS_CLST = 356
SYSZ_INS_CLY = 357
SYSZ_INS_CPSDR = 358
SYSZ_INS_CR = 359
SYSZ_INS_CRL = 360
SYSZ_INS_CS = 361
SYSZ_INS_CSG = 362
SYSZ_INS_CSY = 363
SYSZ_INS_CXBR = 364
SYSZ_INS_CXFBR = 365
SYSZ_INS_CXGBR = 366
SYSZ_INS_CXLFBR = 367
SYSZ_INS_CXLGBR = 368
SYSZ_INS_CY = 369
SYSZ_INS_DDB = 370
SYSZ_INS_DDBR = 371
SYSZ_INS_DEB = 372
SYSZ_INS_DEBR = 373
SYSZ_INS_DL = 374
SYSZ_INS_DLG = 375
SYSZ_INS_DLGR = 376
SYSZ_INS_DLR = 377
SYSZ_INS_DSG = 378
SYSZ_INS_DSGF = 379
SYSZ_INS_DSGFR = 380
SYSZ_INS_DSGR = 381
SYSZ_INS_DXBR = 382
SYSZ_INS_EAR = 383
SYSZ_INS_FIDBR = 384
SYSZ_INS_FIDBRA = 385
SYSZ_INS_FIEBR = 386
SYSZ_INS_FIEBRA = 387
SYSZ_INS_FIXBR = 388
SYSZ_INS_FIXBRA = 389
SYSZ_INS_FLOGR = 390
SYSZ_INS_IC = 391
SYSZ_INS_ICY = 392
SYSZ_INS_IIHF = 393
SYSZ_INS_IIHH = 394
SYSZ_INS_IIHL = 395
SYSZ_INS_IILF = 396
SYSZ_INS_IILH = 397
SYSZ_INS_IILL = 398
SYSZ_INS_IPM = 399
SYSZ_INS_L = 400
SYSZ_INS_LA = 401
SYSZ_INS_LAA = 402
SYSZ_INS_LAAG = 403
SYSZ_INS_LAAL = 404
SYSZ_INS_LAALG = 405
SYSZ_INS_LAN = 406
SYSZ_INS_LANG = 407
SYSZ_INS_LAO = 408
SYSZ_INS_LAOG = 409
SYSZ_INS_LARL = 410
SYSZ_INS_LAX = 411
SYSZ_INS_LAXG = 412
SYSZ_INS_LAY = 413
SYSZ_INS_LB = 414
SYSZ_INS_LBH = 415
SYSZ_INS_LBR = 416
SYSZ_INS_LCDBR = 417
SYSZ_INS_LCEBR = 418
SYSZ_INS_LCGFR = 419
SYSZ_INS_LCGR = 420
SYSZ_INS_LCR = 421
SYSZ_INS_LCXBR = 422
SYSZ_INS_LD = 423
SYSZ_INS_LDEB = 424
SYSZ_INS_LDEBR = 425
SYSZ_INS_LDGR = 426
SYSZ_INS_LDR = 427
SYSZ_INS_LDXBR = 428
SYSZ_INS_LDXBRA = 429
SYSZ_INS_LDY = 430
SYSZ_INS_LE = 431
SYSZ_INS_LEDBR = 432
SYSZ_INS_LEDBRA = 433
SYSZ_INS_LER = 434
SYSZ_INS_LEXBR = 435
SYSZ_INS_LEXBRA = 436
SYSZ_INS_LEY = 437
SYSZ_INS_LFH = 438
SYSZ_INS_LG = 439
SYSZ_INS_LGB = 440
SYSZ_INS_LGBR = 441
SYSZ_INS_LGDR = 442
SYSZ_INS_LGF = 443
SYSZ_INS_LGFI = 444
SYSZ_INS_LGFR = 445
SYSZ_INS_LGFRL = 446
SYSZ_INS_LGH = 447
SYSZ_INS_LGHI = 448
SYSZ_INS_LGHR = 449
SYSZ_INS_LGHRL = 450
SYSZ_INS_LGR = 451
SYSZ_INS_LGRL = 452
SYSZ_INS_LH = 453
SYSZ_INS_LHH = 454
SYSZ_INS_LHI = 455
SYSZ_INS_LHR = 456
SYSZ_INS_LHRL = 457
SYSZ_INS_LHY = 458
SYSZ_INS_LLC = 459
SYSZ_INS_LLCH = 460
SYSZ_INS_LLCR = 461
SYSZ_INS_LLGC = 462
SYSZ_INS_LLGCR = 463
SYSZ_INS_LLGF = 464
SYSZ_INS_LLGFR = 465
SYSZ_INS_LLGFRL = 466
SYSZ_INS_LLGH = 467
SYSZ_INS_LLGHR = 468
SYSZ_INS_LLGHRL = 469
SYSZ_INS_LLH = 470
SYSZ_INS_LLHH = 471
SYSZ_INS_LLHR = 472
SYSZ_INS_LLHRL = 473
SYSZ_INS_LLIHF = 474
SYSZ_INS_LLIHH = 475
SYSZ_INS_LLIHL = 476
SYSZ_INS_LLILF = 477
SYSZ_INS_LLILH = 478
SYSZ_INS_LLILL = 479
SYSZ_INS_LMG = 480
SYSZ_INS_LNDBR = 481
SYSZ_INS_LNEBR = 482
SYSZ_INS_LNGFR = 483
SYSZ_INS_LNGR = 484
SYSZ_INS_LNR = 485
SYSZ_INS_LNXBR = 486
SYSZ_INS_LPDBR = 487
SYSZ_INS_LPEBR = 488
SYSZ_INS_LPGFR = 489
SYSZ_INS_LPGR = 490
SYSZ_INS_LPR = 491
SYSZ_INS_LPXBR = 492
SYSZ_INS_LR = 493
SYSZ_INS_LRL = 494
SYSZ_INS_LRV = 495
SYSZ_INS_LRVG = 496
SYSZ_INS_LRVGR = 497
SYSZ_INS_LRVR = 498
SYSZ_INS_LT = 499
SYSZ_INS_LTDBR = 500
SYSZ_INS_LTEBR = 501
SYSZ_INS_LTG = 502
SYSZ_INS_LTGF = 503
SYSZ_INS_LTGFR = 504
SYSZ_INS_LTGR = 505
SYSZ_INS_LTR = 506
SYSZ_INS_LTXBR = 507
SYSZ_INS_LXDB = 508
SYSZ_INS_LXDBR = 509
SYSZ_INS_LXEB = 510
SYSZ_INS_LXEBR = 511
SYSZ_INS_LXR = 512
SYSZ_INS_LY = 513
SYSZ_INS_LZDR = 514
SYSZ_INS_LZER = 515
SYSZ_INS_LZXR = 516
SYSZ_INS_MADB = 517
SYSZ_INS_MADBR = 518
SYSZ_INS_MAEB = 519
SYSZ_INS_MAEBR = 520
SYSZ_INS_MDB = 521
SYSZ_INS_MDBR = 522
SYSZ_INS_MDEB = 523
SYSZ_INS_MDEBR = 524
SYSZ_INS_MEEB = 525
SYSZ_INS_MEEBR = 526
SYSZ_INS_MGHI = 527
SYSZ_INS_MH = 528
SYSZ_INS_MHI = 529
SYSZ_INS_MHY = 530
SYSZ_INS_MLG = 531
SYSZ_INS_MLGR = 532
SYSZ_INS_MS = 533
SYSZ_INS_MSDB = 534
SYSZ_INS_MSDBR = 535
SYSZ_INS_MSEB = 536
SYSZ_INS_MSEBR = 537
SYSZ_INS_MSFI = 538
SYSZ_INS_MSG = 539
SYSZ_INS_MSGF = 540
SYSZ_INS_MSGFI = 541
SYSZ_INS_MSGFR = 542
SYSZ_INS_MSGR = 543
SYSZ_INS_MSR = 544
SYSZ_INS_MSY = 545
SYSZ_INS_MVC = 546
SYSZ_INS_MVGHI = 547
SYSZ_INS_MVHHI = 548
SYSZ_INS_MVHI = 549
SYSZ_INS_MVI = 550
SYSZ_INS_MVIY = 551
SYSZ_INS_MVST = 552
SYSZ_INS_MXBR = 553
SYSZ_INS_MXDB = 554
SYSZ_INS_MXDBR = 555
SYSZ_INS_N = 556
SYSZ_INS_NC = 557
SYSZ_INS_NG = 558
SYSZ_INS_NGR = 559
SYSZ_INS_NGRK = 560
SYSZ_INS_NI = 561
SYSZ_INS_NIHF = 562
SYSZ_INS_NIHH = 563
SYSZ_INS_NIHL = 564
SYSZ_INS_NILF = 565
SYSZ_INS_NILH = 566
SYSZ_INS_NILL = 567
SYSZ_INS_NIY = 568
SYSZ_INS_NR = 569
SYSZ_INS_NRK = 570
SYSZ_INS_NY = 571
SYSZ_INS_O = 572
SYSZ_INS_OC = 573
SYSZ_INS_OG = 574
SYSZ_INS_OGR = 575
SYSZ_INS_OGRK = 576
SYSZ_INS_OI = 577
SYSZ_INS_OIHF = 578
SYSZ_INS_OIHH = 579
SYSZ_INS_OIHL = 580
SYSZ_INS_OILF = 581
SYSZ_INS_OILH = 582
SYSZ_INS_OILL = 583
SYSZ_INS_OIY = 584
SYSZ_INS_OR = 585
SYSZ_INS_ORK = 586
SYSZ_INS_OY = 587
SYSZ_INS_PFD = 588
SYSZ_INS_PFDRL = 589
SYSZ_INS_RISBG = 590
SYSZ_INS_RISBHG = 591
SYSZ_INS_RISBLG = 592
SYSZ_INS_RLL = 593
SYSZ_INS_RLLG = 594
SYSZ_INS_RNSBG = 595
SYSZ_INS_ROSBG = 596
SYSZ_INS_RXSBG = 597
SYSZ_INS_S = 598
SYSZ_INS_SDB = 599
SYSZ_INS_SDBR = 600
SYSZ_INS_SEB = 601
SYSZ_INS_SEBR = 602
SYSZ_INS_SG = 603
SYSZ_INS_SGF = 604
SYSZ_INS_SGFR = 605
SYSZ_INS_SGR = 606
SYSZ_INS_SGRK = 607
SYSZ_INS_SH = 608
SYSZ_INS_SHY = 609
SYSZ_INS_SL = 610
SYSZ_INS_SLB = 611
SYSZ_INS_SLBG = 612
SYSZ_INS_SLBR = 613
SYSZ_INS_SLFI = 614
SYSZ_INS_SLG = 615
SYSZ_INS_SLBGR = 616
SYSZ_INS_SLGF = 617
SYSZ_INS_SLGFI = 618
SYSZ_INS_SLGFR = 619
SYSZ_INS_SLGR = 620
SYSZ_INS_SLGRK = 621
SYSZ_INS_SLL = 622
SYSZ_INS_SLLG = 623
SYSZ_INS_SLLK = 624
SYSZ_INS_SLR = 625
SYSZ_INS_SLRK = 626
SYSZ_INS_SLY = 627
SYSZ_INS_SQDB = 628
SYSZ_INS_SQDBR = 629
SYSZ_INS_SQEB = 630
SYSZ_INS_SQEBR = 631
SYSZ_INS_SQXBR = 632
SYSZ_INS_SR = 633
SYSZ_INS_SRA = 634
SYSZ_INS_SRAG = 635
SYSZ_INS_SRAK = 636
SYSZ_INS_SRK = 637
SYSZ_INS_SRL = 638
SYSZ_INS_SRLG = 639
SYSZ_INS_SRLK = 640
SYSZ_INS_SRST = 641
SYSZ_INS_ST = 642
SYSZ_INS_STC = 643
SYSZ_INS_STCH = 644
SYSZ_INS_STCY = 645
SYSZ_INS_STD = 646
SYSZ_INS_STDY = 647
SYSZ_INS_STE = 648
SYSZ_INS_STEY = 649
SYSZ_INS_STFH = 650
SYSZ_INS_STG = 651
SYSZ_INS_STGRL = 652
SYSZ_INS_STH = 653
SYSZ_INS_STHH = 654
SYSZ_INS_STHRL = 655
SYSZ_INS_STHY = 656
SYSZ_INS_STMG = 657
SYSZ_INS_STRL = 658
SYSZ_INS_STRV = 659
SYSZ_INS_STRVG = 660
SYSZ_INS_STY = 661
SYSZ_INS_SXBR = 662
SYSZ_INS_SY = 663
SYSZ_INS_TM = 664
SYSZ_INS_TMHH = 665
SYSZ_INS_TMHL = 666
SYSZ_INS_TMLH = 667
SYSZ_INS_TMLL = 668
SYSZ_INS_TMY = 669
SYSZ_INS_X = 670
SYSZ_INS_XC = 671
SYSZ_INS_XG = 672
SYSZ_INS_XGR = 673
SYSZ_INS_XGRK = 674
SYSZ_INS_XI = 675
SYSZ_INS_XIHF = 676
SYSZ_INS_XILF = 677
SYSZ_INS_XIY = 678
SYSZ_INS_XR = 679
SYSZ_INS_XRK = 680
SYSZ_INS_XY = 681
SYSZ_INS_AD = 682
SYSZ_INS_ADR = 683
SYSZ_INS_ADTR = 684
SYSZ_INS_ADTRA = 685
SYSZ_INS_AE = 686
SYSZ_INS_AER = 687
SYSZ_INS_AGH = 688
SYSZ_INS_AHHHR = 689
SYSZ_INS_AHHLR = 690
SYSZ_INS_ALGSI = 691
SYSZ_INS_ALHHHR = 692
SYSZ_INS_ALHHLR = 693
SYSZ_INS_ALSI = 694
SYSZ_INS_ALSIH = 695
SYSZ_INS_ALSIHN = 696
SYSZ_INS_AP = 697
SYSZ_INS_AU = 698
SYSZ_INS_AUR = 699
SYSZ_INS_AW = 700
SYSZ_INS_AWR = 701
SYSZ_INS_AXR = 702
SYSZ_INS_AXTR = 703
SYSZ_INS_AXTRA = 704
SYSZ_INS_B = 705
SYSZ_INS_BAKR = 706
SYSZ_INS_BAL = 707
SYSZ_INS_BALR = 708
SYSZ_INS_BAS = 709
SYSZ_INS_BASSM = 710
SYSZ_INS_BC = 711
SYSZ_INS_BCT = 712
SYSZ_INS_BCTG = 713
SYSZ_INS_BCTGR = 714
SYSZ_INS_BCTR = 715
SYSZ_INS_BE = 716
SYSZ_INS_BH = 717
SYSZ_INS_BHE = 718
SYSZ_INS_BI = 719
SYSZ_INS_BIC = 720
SYSZ_INS_BIE = 721
SYSZ_INS_BIH = 722
SYSZ_INS_BIHE = 723
SYSZ_INS_BIL = 724
SYSZ_INS_BILE = 725
SYSZ_INS_BILH = 726
SYSZ_INS_BIM = 727
SYSZ_INS_BINE = 728
SYSZ_INS_BINH = 729
SYSZ_INS_BINHE = 730
SYSZ_INS_BINL = 731
SYSZ_INS_BINLE = 732
SYSZ_INS_BINLH = 733
SYSZ_INS_BINM = 734
SYSZ_INS_BINO = 735
SYSZ_INS_BINP = 736
SYSZ_INS_BINZ = 737
SYSZ_INS_BIO = 738
SYSZ_INS_BIP = 739
SYSZ_INS_BIZ = 740
SYSZ_INS_BL = 741
SYSZ_INS_BLE = 742
SYSZ_INS_BLH = 743
SYSZ_INS_BM = 744
SYSZ_INS_BMR = 745
SYSZ_INS_BNE = 746
SYSZ_INS_BNH = 747
SYSZ_INS_BNHE = 748
SYSZ_INS_BNL = 749
SYSZ_INS_BNLE = 750
SYSZ_INS_BNLH = 751
SYSZ_INS_BNM = 752
SYSZ_INS_BNMR = 753
SYSZ_INS_BNO = 754
SYSZ_INS_BNP = 755
SYSZ_INS_BNPR = 756
SYSZ_INS_BNZ = 757
SYSZ_INS_BNZR = 758
SYSZ_INS_BO = 759
SYSZ_INS_BP = 760
SYSZ_INS_BPP = 761
SYSZ_INS_BPR = 762
SYSZ_INS_BPRP = 763
SYSZ_INS_BRCTH = 764
SYSZ_INS_BRXH = 765
SYSZ_INS_BRXHG = 766
SYSZ_INS_BRXLE = 767
SYSZ_INS_BRXLG = 768
SYSZ_INS_BSA = 769
SYSZ_INS_BSG = 770
SYSZ_INS_BSM = 771
SYSZ_INS_BXH = 772
SYSZ_INS_BXHG = 773
SYSZ_INS_BXLE = 774
SYSZ_INS_BXLEG = 775
SYSZ_INS_BZ = 776
SYSZ_INS_BZR = 777
SYSZ_INS_CD = 778
SYSZ_INS_CDFBRA = 779
SYSZ_INS_CDFR = 780
SYSZ_INS_CDFTR = 781
SYSZ_INS_CDGBRA = 782
SYSZ_INS_CDGR = 783
SYSZ_INS_CDGTR = 784
SYSZ_INS_CDGTRA = 785
SYSZ_INS_CDLFTR = 786
SYSZ_INS_CDLGTR = 787
SYSZ_INS_CDPT = 788
SYSZ_INS_CDR = 789
SYSZ_INS_CDS = 790
SYSZ_INS_CDSG = 791
SYSZ_INS_CDSTR = 792
SYSZ_INS_CDSY = 793
SYSZ_INS_CDTR = 794
SYSZ_INS_CDUTR = 795
SYSZ_INS_CDZT = 796
SYSZ_INS_CE = 797
SYSZ_INS_CEDTR = 798
SYSZ_INS_CEFBRA = 799
SYSZ_INS_CEFR = 800
SYSZ_INS_CEGBRA = 801
SYSZ_INS_CEGR = 802
SYSZ_INS_CER = 803
SYSZ_INS_CEXTR = 804
SYSZ_INS_CFC = 805
SYSZ_INS_CFDBRA = 806
SYSZ_INS_CFDR = 807
SYSZ_INS_CFDTR = 808
SYSZ_INS_CFEBRA = 809
SYSZ_INS_CFER = 810
SYSZ_INS_CFXBRA = 811
SYSZ_INS_CFXR = 812
SYSZ_INS_CFXTR = 813
SYSZ_INS_CGDBRA = 814
SYSZ_INS_CGDR = 815
SYSZ_INS_CGDTR = 816
SYSZ_INS_CGDTRA = 817
SYSZ_INS_CGEBRA = 818
SYSZ_INS_CGER = 819
SYSZ_INS_CGIB = 820
SYSZ_INS_CGIBE = 821
SYSZ_INS_CGIBH = 822
SYSZ_INS_CGIBHE = 823
SYSZ_INS_CGIBL = 824
SYSZ_INS_CGIBLE = 825
SYSZ_INS_CGIBLH = 826
SYSZ_INS_CGIBNE = 827
SYSZ_INS_CGIBNH = 828
SYSZ_INS_CGIBNHE = 829
SYSZ_INS_CGIBNL = 830
SYSZ_INS_CGIBNLE = 831
SYSZ_INS_CGIBNLH = 832
SYSZ_INS_CGIT = 833
SYSZ_INS_CGITE = 834
SYSZ_INS_CGITH = 835
SYSZ_INS_CGITHE = 836
SYSZ_INS_CGITL = 837
SYSZ_INS_CGITLE = 838
SYSZ_INS_CGITLH = 839
SYSZ_INS_CGITNE = 840
SYSZ_INS_CGITNH = 841
SYSZ_INS_CGITNHE = 842
SYSZ_INS_CGITNL = 843
SYSZ_INS_CGITNLE = 844
SYSZ_INS_CGITNLH = 845
SYSZ_INS_CGRB = 846
SYSZ_INS_CGRBE = 847
SYSZ_INS_CGRBH = 848
SYSZ_INS_CGRBHE = 849
SYSZ_INS_CGRBL = 850
SYSZ_INS_CGRBLE = 851
SYSZ_INS_CGRBLH = 852
SYSZ_INS_CGRBNE = 853
SYSZ_INS_CGRBNH = 854
SYSZ_INS_CGRBNHE = 855
SYSZ_INS_CGRBNL = 856
SYSZ_INS_CGRBNLE = 857
SYSZ_INS_CGRBNLH = 858
SYSZ_INS_CGRT = 859
SYSZ_INS_CGRTE = 860
SYSZ_INS_CGRTH = 861
SYSZ_INS_CGRTHE = 862
SYSZ_INS_CGRTL = 863
SYSZ_INS_CGRTLE = 864
SYSZ_INS_CGRTLH = 865
SYSZ_INS_CGRTNE = 866
SYSZ_INS_CGRTNH = 867
SYSZ_INS_CGRTNHE = 868
SYSZ_INS_CGRTNL = 869
SYSZ_INS_CGRTNLE = 870
SYSZ_INS_CGRTNLH = 871
SYSZ_INS_CGXBRA = 872
SYSZ_INS_CGXR = 873
SYSZ_INS_CGXTR = 874
SYSZ_INS_CGXTRA = 875
SYSZ_INS_CHHR = 876
SYSZ_INS_CHLR = 877
SYSZ_INS_CIB = 878
SYSZ_INS_CIBE = 879
SYSZ_INS_CIBH = 880
SYSZ_INS_CIBHE = 881
SYSZ_INS_CIBL = 882
SYSZ_INS_CIBLE = 883
SYSZ_INS_CIBLH = 884
SYSZ_INS_CIBNE = 885
SYSZ_INS_CIBNH = 886
SYSZ_INS_CIBNHE = 887
SYSZ_INS_CIBNL = 888
SYSZ_INS_CIBNLE = 889
SYSZ_INS_CIBNLH = 890
SYSZ_INS_CIT = 891
SYSZ_INS_CITE = 892
SYSZ_INS_CITH = 893
SYSZ_INS_CITHE = 894
SYSZ_INS_CITL = 895
SYSZ_INS_CITLE = 896
SYSZ_INS_CITLH = 897
SYSZ_INS_CITNE = 898
SYSZ_INS_CITNH = 899
SYSZ_INS_CITNHE = 900
SYSZ_INS_CITNL = 901
SYSZ_INS_CITNLE = 902
SYSZ_INS_CITNLH = 903
SYSZ_INS_CKSM = 904
SYSZ_INS_CLCL = 905
SYSZ_INS_CLCLE = 906
SYSZ_INS_CLCLU = 907
SYSZ_INS_CLFDTR = 908
SYSZ_INS_CLFIT = 909
SYSZ_INS_CLFITE = 910
SYSZ_INS_CLFITH = 911
SYSZ_INS_CLFITHE = 912
SYSZ_INS_CLFITL = 913
SYSZ_INS_CLFITLE = 914
SYSZ_INS_CLFITLH = 915
SYSZ_INS_CLFITNE = 916
SYSZ_INS_CLFITNH = 917
SYSZ_INS_CLFITNHE = 918
SYSZ_INS_CLFITNL = 919
SYSZ_INS_CLFITNLE = 920
SYSZ_INS_CLFITNLH = 921
SYSZ_INS_CLFXTR = 922
SYSZ_INS_CLGDTR = 923
SYSZ_INS_CLGIB = 924
SYSZ_INS_CLGIBE = 925
SYSZ_INS_CLGIBH = 926
SYSZ_INS_CLGIBHE = 927
SYSZ_INS_CLGIBL = 928
SYSZ_INS_CLGIBLE = 929
SYSZ_INS_CLGIBLH = 930
SYSZ_INS_CLGIBNE = 931
SYSZ_INS_CLGIBNH = 932
SYSZ_INS_CLGIBNHE = 933
SYSZ_INS_CLGIBNL = 934
SYSZ_INS_CLGIBNLE = 935
SYSZ_INS_CLGIBNLH = 936
SYSZ_INS_CLGIT = 937
SYSZ_INS_CLGITE = 938
SYSZ_INS_CLGITH = 939
SYSZ_INS_CLGITHE = 940
SYSZ_INS_CLGITL = 941
SYSZ_INS_CLGITLE = 942
SYSZ_INS_CLGITLH = 943
SYSZ_INS_CLGITNE = 944
SYSZ_INS_CLGITNH = 945
SYSZ_INS_CLGITNHE = 946
SYSZ_INS_CLGITNL = 947
SYSZ_INS_CLGITNLE = 948
SYSZ_INS_CLGITNLH = 949
SYSZ_INS_CLGRB = 950
SYSZ_INS_CLGRBE = 951
SYSZ_INS_CLGRBH = 952
SYSZ_INS_CLGRBHE = 953
SYSZ_INS_CLGRBL = 954
SYSZ_INS_CLGRBLE = 955
SYSZ_INS_CLGRBLH = 956
SYSZ_INS_CLGRBNE = 957
SYSZ_INS_CLGRBNH = 958
SYSZ_INS_CLGRBNHE = 959
SYSZ_INS_CLGRBNL = 960
SYSZ_INS_CLGRBNLE = 961
SYSZ_INS_CLGRBNLH = 962
SYSZ_INS_CLGRT = 963
SYSZ_INS_CLGRTE = 964
SYSZ_INS_CLGRTH = 965
SYSZ_INS_CLGRTHE = 966
SYSZ_INS_CLGRTL = 967
SYSZ_INS_CLGRTLE = 968
SYSZ_INS_CLGRTLH = 969
SYSZ_INS_CLGRTNE = 970
SYSZ_INS_CLGRTNH = 971
SYSZ_INS_CLGRTNHE = 972
SYSZ_INS_CLGRTNL = 973
SYSZ_INS_CLGRTNLE = 974
SYSZ_INS_CLGRTNLH = 975
SYSZ_INS_CLGT = 976
SYSZ_INS_CLGTE = 977
SYSZ_INS_CLGTH = 978
SYSZ_INS_CLGTHE = 979
SYSZ_INS_CLGTL = 980
SYSZ_INS_CLGTLE = 981
SYSZ_INS_CLGTLH = 982
SYSZ_INS_CLGTNE = 983
SYSZ_INS_CLGTNH = 984
SYSZ_INS_CLGTNHE = 985
SYSZ_INS_CLGTNL = 986
SYSZ_INS_CLGTNLE = 987
SYSZ_INS_CLGTNLH = 988
SYSZ_INS_CLGXTR = 989
SYSZ_INS_CLHHR = 990
SYSZ_INS_CLHLR = 991
SYSZ_INS_CLIB = 992
SYSZ_INS_CLIBE = 993
SYSZ_INS_CLIBH = 994
SYSZ_INS_CLIBHE = 995
SYSZ_INS_CLIBL = 996
SYSZ_INS_CLIBLE = 997
SYSZ_INS_CLIBLH = 998
SYSZ_INS_CLIBNE = 999
SYSZ_INS_CLIBNH = 1000
SYSZ_INS_CLIBNHE = 1001
SYSZ_INS_CLIBNL = 1002
SYSZ_INS_CLIBNLE = 1003
SYSZ_INS_CLIBNLH = 1004
SYSZ_INS_CLM = 1005
SYSZ_INS_CLMH = 1006
SYSZ_INS_CLMY = 1007
SYSZ_INS_CLRB = 1008
SYSZ_INS_CLRBE = 1009
SYSZ_INS_CLRBH = 1010
SYSZ_INS_CLRBHE = 1011
SYSZ_INS_CLRBL = 1012
SYSZ_INS_CLRBLE = 1013
SYSZ_INS_CLRBLH = 1014
SYSZ_INS_CLRBNE = 1015
SYSZ_INS_CLRBNH = 1016
SYSZ_INS_CLRBNHE = 1017
SYSZ_INS_CLRBNL = 1018
SYSZ_INS_CLRBNLE = 1019
SYSZ_INS_CLRBNLH = 1020
SYSZ_INS_CLRT = 1021
SYSZ_INS_CLRTE = 1022
SYSZ_INS_CLRTH = 1023
SYSZ_INS_CLRTHE = 1024
SYSZ_INS_CLRTL = 1025
SYSZ_INS_CLRTLE = 1026
SYSZ_INS_CLRTLH = 1027
SYSZ_INS_CLRTNE = 1028
SYSZ_INS_CLRTNH = 1029
SYSZ_INS_CLRTNHE = 1030
SYSZ_INS_CLRTNL = 1031
SYSZ_INS_CLRTNLE = 1032
SYSZ_INS_CLRTNLH = 1033
SYSZ_INS_CLT = 1034
SYSZ_INS_CLTE = 1035
SYSZ_INS_CLTH = 1036
SYSZ_INS_CLTHE = 1037
SYSZ_INS_CLTL = 1038
SYSZ_INS_CLTLE = 1039
SYSZ_INS_CLTLH = 1040
SYSZ_INS_CLTNE = 1041
SYSZ_INS_CLTNH = 1042
SYSZ_INS_CLTNHE = 1043
SYSZ_INS_CLTNL = 1044
SYSZ_INS_CLTNLE = 1045
SYSZ_INS_CLTNLH = 1046
SYSZ_INS_CMPSC = 1047
SYSZ_INS_CP = 1048
SYSZ_INS_CPDT = 1049
SYSZ_INS_CPXT = 1050
SYSZ_INS_CPYA = 1051
SYSZ_INS_CRB = 1052
SYSZ_INS_CRBE = 1053
SYSZ_INS_CRBH = 1054
SYSZ_INS_CRBHE = 1055
SYSZ_INS_CRBL = 1056
SYSZ_INS_CRBLE = 1057
SYSZ_INS_CRBLH = 1058
SYSZ_INS_CRBNE = 1059
SYSZ_INS_CRBNH = 1060
SYSZ_INS_CRBNHE = 1061
SYSZ_INS_CRBNL = 1062
SYSZ_INS_CRBNLE = 1063
SYSZ_INS_CRBNLH = 1064
SYSZ_INS_CRDTE = 1065
SYSZ_INS_CRT = 1066
SYSZ_INS_CRTE = 1067
SYSZ_INS_CRTH = 1068
SYSZ_INS_CRTHE = 1069
SYSZ_INS_CRTL = 1070
SYSZ_INS_CRTLE = 1071
SYSZ_INS_CRTLH = 1072
SYSZ_INS_CRTNE = 1073
SYSZ_INS_CRTNH = 1074
SYSZ_INS_CRTNHE = 1075
SYSZ_INS_CRTNL = 1076
SYSZ_INS_CRTNLE = 1077
SYSZ_INS_CRTNLH = 1078
SYSZ_INS_CSCH = 1079
SYSZ_INS_CSDTR = 1080
SYSZ_INS_CSP = 1081
SYSZ_INS_CSPG = 1082
SYSZ_INS_CSST = 1083
SYSZ_INS_CSXTR = 1084
SYSZ_INS_CU12 = 1085
SYSZ_INS_CU14 = 1086
SYSZ_INS_CU21 = 1087
SYSZ_INS_CU24 = 1088
SYSZ_INS_CU41 = 1089
SYSZ_INS_CU42 = 1090
SYSZ_INS_CUDTR = 1091
SYSZ_INS_CUSE = 1092
SYSZ_INS_CUTFU = 1093
SYSZ_INS_CUUTF = 1094
SYSZ_INS_CUXTR = 1095
SYSZ_INS_CVB = 1096
SYSZ_INS_CVBG = 1097
SYSZ_INS_CVBY = 1098
SYSZ_INS_CVD = 1099
SYSZ_INS_CVDG = 1100
SYSZ_INS_CVDY = 1101
SYSZ_INS_CXFBRA = 1102
SYSZ_INS_CXFR = 1103
SYSZ_INS_CXFTR = 1104
SYSZ_INS_CXGBRA = 1105
SYSZ_INS_CXGR = 1106
SYSZ_INS_CXGTR = 1107
SYSZ_INS_CXGTRA = 1108
SYSZ_INS_CXLFTR = 1109
SYSZ_INS_CXLGTR = 1110
SYSZ_INS_CXPT = 1111
SYSZ_INS_CXR = 1112
SYSZ_INS_CXSTR = 1113
SYSZ_INS_CXTR = 1114
SYSZ_INS_CXUTR = 1115
SYSZ_INS_CXZT = 1116
SYSZ_INS_CZDT = 1117
SYSZ_INS_CZXT = 1118
SYSZ_INS_D = 1119
SYSZ_INS_DD = 1120
SYSZ_INS_DDR = 1121
SYSZ_INS_DDTR = 1122
SYSZ_INS_DDTRA = 1123
SYSZ_INS_DE = 1124
SYSZ_INS_DER = 1125
SYSZ_INS_DIAG = 1126
SYSZ_INS_DIDBR = 1127
SYSZ_INS_DIEBR = 1128
SYSZ_INS_DP = 1129
SYSZ_INS_DR = 1130
SYSZ_INS_DXR = 1131
SYSZ_INS_DXTR = 1132
SYSZ_INS_DXTRA = 1133
SYSZ_INS_ECAG = 1134
SYSZ_INS_ECCTR = 1135
SYSZ_INS_ECPGA = 1136
SYSZ_INS_ECTG = 1137
SYSZ_INS_ED = 1138
SYSZ_INS_EDMK = 1139
SYSZ_INS_EEDTR = 1140
SYSZ_INS_EEXTR = 1141
SYSZ_INS_EFPC = 1142
SYSZ_INS_EPAIR = 1143
SYSZ_INS_EPAR = 1144
SYSZ_INS_EPCTR = 1145
SYSZ_INS_EPSW = 1146
SYSZ_INS_EREG = 1147
SYSZ_INS_EREGG = 1148
SYSZ_INS_ESAIR = 1149
SYSZ_INS_ESAR = 1150
SYSZ_INS_ESDTR = 1151
SYSZ_INS_ESEA = 1152
SYSZ_INS_ESTA = 1153
SYSZ_INS_ESXTR = 1154
SYSZ_INS_ETND = 1155
SYSZ_INS_EX = 1156
SYSZ_INS_EXRL = 1157
SYSZ_INS_FIDR = 1158
SYSZ_INS_FIDTR = 1159
SYSZ_INS_FIER = 1160
SYSZ_INS_FIXR = 1161
SYSZ_INS_FIXTR = 1162
SYSZ_INS_HDR = 1163
SYSZ_INS_HER = 1164
SYSZ_INS_HSCH = 1165
SYSZ_INS_IAC = 1166
SYSZ_INS_ICM = 1167
SYSZ_INS_ICMH = 1168
SYSZ_INS_ICMY = 1169
SYSZ_INS_IDTE = 1170
SYSZ_INS_IEDTR = 1171
SYSZ_INS_IEXTR = 1172
SYSZ_INS_IPK = 1173
SYSZ_INS_IPTE = 1174
SYSZ_INS_IRBM = 1175
SYSZ_INS_ISKE = 1176
SYSZ_INS_IVSK = 1177
SYSZ_INS_JGM = 1178
SYSZ_INS_JGNM = 1179
SYSZ_INS_JGNP = 1180
SYSZ_INS_JGNZ = 1181
SYSZ_INS_JGP = 1182
SYSZ_INS_JGZ = 1183
SYSZ_INS_JM = 1184
SYSZ_INS_JNM = 1185
SYSZ_INS_JNP = 1186
SYSZ_INS_JNZ = 1187
SYSZ_INS_JP = 1188
SYSZ_INS_JZ = 1189
SYSZ_INS_KDB = 1190
SYSZ_INS_KDBR = 1191
SYSZ_INS_KDTR = 1192
SYSZ_INS_KEB = 1193
SYSZ_INS_KEBR = 1194
SYSZ_INS_KIMD = 1195
SYSZ_INS_KLMD = 1196
SYSZ_INS_KM = 1197
SYSZ_INS_KMA = 1198
SYSZ_INS_KMAC = 1199
SYSZ_INS_KMC = 1200
SYSZ_INS_KMCTR = 1201
SYSZ_INS_KMF = 1202
SYSZ_INS_KMO = 1203
SYSZ_INS_KXBR = 1204
SYSZ_INS_KXTR = 1205
SYSZ_INS_LAE = 1206
SYSZ_INS_LAEY = 1207
SYSZ_INS_LAM = 1208
SYSZ_INS_LAMY = 1209
SYSZ_INS_LASP = 1210
SYSZ_INS_LAT = 1211
SYSZ_INS_LCBB = 1212
SYSZ_INS_LCCTL = 1213
SYSZ_INS_LCDFR = 1214
SYSZ_INS_LCDR = 1215
SYSZ_INS_LCER = 1216
SYSZ_INS_LCTL = 1217
SYSZ_INS_LCTLG = 1218
SYSZ_INS_LCXR = 1219
SYSZ_INS_LDE = 1220
SYSZ_INS_LDER = 1221
SYSZ_INS_LDETR = 1222
SYSZ_INS_LDXR = 1223
SYSZ_INS_LDXTR = 1224
SYSZ_INS_LEDR = 1225
SYSZ_INS_LEDTR = 1226
SYSZ_INS_LEXR = 1227
SYSZ_INS_LFAS = 1228
SYSZ_INS_LFHAT = 1229
SYSZ_INS_LFPC = 1230
SYSZ_INS_LGAT = 1231
SYSZ_INS_LGG = 1232
SYSZ_INS_LGSC = 1233
SYSZ_INS_LLGFAT = 1234
SYSZ_INS_LLGFSG = 1235
SYSZ_INS_LLGT = 1236
SYSZ_INS_LLGTAT = 1237
SYSZ_INS_LLGTR = 1238
SYSZ_INS_LLZRGF = 1239
SYSZ_INS_LM = 1240
SYSZ_INS_LMD = 1241
SYSZ_INS_LMH = 1242
SYSZ_INS_LMY = 1243
SYSZ_INS_LNDFR = 1244
SYSZ_INS_LNDR = 1245
SYSZ_INS_LNER = 1246
SYSZ_INS_LNXR = 1247
SYSZ_INS_LOCFH = 1248
SYSZ_INS_LOCFHE = 1249
SYSZ_INS_LOCFHH = 1250
SYSZ_INS_LOCFHHE = 1251
SYSZ_INS_LOCFHL = 1252
SYSZ_INS_LOCFHLE = 1253
SYSZ_INS_LOCFHLH = 1254
SYSZ_INS_LOCFHM = 1255
SYSZ_INS_LOCFHNE = 1256
SYSZ_INS_LOCFHNH = 1257
SYSZ_INS_LOCFHNHE = 1258
SYSZ_INS_LOCFHNL = 1259
SYSZ_INS_LOCFHNLE = 1260
SYSZ_INS_LOCFHNLH = 1261
SYSZ_INS_LOCFHNM = 1262
SYSZ_INS_LOCFHNO = 1263
SYSZ_INS_LOCFHNP = 1264
SYSZ_INS_LOCFHNZ = 1265
SYSZ_INS_LOCFHO = 1266
SYSZ_INS_LOCFHP = 1267
SYSZ_INS_LOCFHR = 1268
SYSZ_INS_LOCFHRE = 1269
SYSZ_INS_LOCFHRH = 1270
SYSZ_INS_LOCFHRHE = 1271
SYSZ_INS_LOCFHRL = 1272
SYSZ_INS_LOCFHRLE = 1273
SYSZ_INS_LOCFHRLH = 1274
SYSZ_INS_LOCFHRM = 1275
SYSZ_INS_LOCFHRNE = 1276
SYSZ_INS_LOCFHRNH = 1277
SYSZ_INS_LOCFHRNHE = 1278
SYSZ_INS_LOCFHRNL = 1279
SYSZ_INS_LOCFHRNLE = 1280
SYSZ_INS_LOCFHRNLH = 1281
SYSZ_INS_LOCFHRNM = 1282
SYSZ_INS_LOCFHRNO = 1283
SYSZ_INS_LOCFHRNP = 1284
SYSZ_INS_LOCFHRNZ = 1285
SYSZ_INS_LOCFHRO = 1286
SYSZ_INS_LOCFHRP = 1287
SYSZ_INS_LOCFHRZ = 1288
SYSZ_INS_LOCFHZ = 1289
SYSZ_INS_LOCGHI = 1290
SYSZ_INS_LOCGHIE = 1291
SYSZ_INS_LOCGHIH = 1292
SYSZ_INS_LOCGHIHE = 1293
SYSZ_INS_LOCGHIL = 1294
SYSZ_INS_LOCGHILE = 1295
SYSZ_INS_LOCGHILH = 1296
SYSZ_INS_LOCGHIM = 1297
SYSZ_INS_LOCGHINE = 1298
SYSZ_INS_LOCGHINH = 1299
SYSZ_INS_LOCGHINHE = 1300
SYSZ_INS_LOCGHINL = 1301
SYSZ_INS_LOCGHINLE = 1302
SYSZ_INS_LOCGHINLH = 1303
SYSZ_INS_LOCGHINM = 1304
SYSZ_INS_LOCGHINO = 1305
SYSZ_INS_LOCGHINP = 1306
SYSZ_INS_LOCGHINZ = 1307
SYSZ_INS_LOCGHIO = 1308
SYSZ_INS_LOCGHIP = 1309
SYSZ_INS_LOCGHIZ = 1310
SYSZ_INS_LOCGM = 1311
SYSZ_INS_LOCGNM = 1312
SYSZ_INS_LOCGNP = 1313
SYSZ_INS_LOCGNZ = 1314
SYSZ_INS_LOCGP = 1315
SYSZ_INS_LOCGRM = 1316
SYSZ_INS_LOCGRNM = 1317
SYSZ_INS_LOCGRNP = 1318
SYSZ_INS_LOCGRNZ = 1319
SYSZ_INS_LOCGRP = 1320
SYSZ_INS_LOCGRZ = 1321
SYSZ_INS_LOCGZ = 1322
SYSZ_INS_LOCHHI = 1323
SYSZ_INS_LOCHHIE = 1324
SYSZ_INS_LOCHHIH = 1325
SYSZ_INS_LOCHHIHE = 1326
SYSZ_INS_LOCHHIL = 1327
SYSZ_INS_LOCHHILE = 1328
SYSZ_INS_LOCHHILH = 1329
SYSZ_INS_LOCHHIM = 1330
SYSZ_INS_LOCHHINE = 1331
SYSZ_INS_LOCHHINH = 1332
SYSZ_INS_LOCHHINHE = 1333
SYSZ_INS_LOCHHINL = 1334
SYSZ_INS_LOCHHINLE = 1335
SYSZ_INS_LOCHHINLH = 1336
SYSZ_INS_LOCHHINM = 1337
SYSZ_INS_LOCHHINO = 1338
SYSZ_INS_LOCHHINP = 1339
SYSZ_INS_LOCHHINZ = 1340
SYSZ_INS_LOCHHIO = 1341
SYSZ_INS_LOCHHIP = 1342
SYSZ_INS_LOCHHIZ = 1343
SYSZ_INS_LOCHI = 1344
SYSZ_INS_LOCHIE = 1345
SYSZ_INS_LOCHIH = 1346
SYSZ_INS_LOCHIHE = 1347
SYSZ_INS_LOCHIL = 1348
SYSZ_INS_LOCHILE = 1349
SYSZ_INS_LOCHILH = 1350
SYSZ_INS_LOCHIM = 1351
SYSZ_INS_LOCHINE = 1352
SYSZ_INS_LOCHINH = 1353
SYSZ_INS_LOCHINHE = 1354
SYSZ_INS_LOCHINL = 1355
SYSZ_INS_LOCHINLE = 1356
SYSZ_INS_LOCHINLH = 1357
SYSZ_INS_LOCHINM = 1358
SYSZ_INS_LOCHINO = 1359
SYSZ_INS_LOCHINP = 1360
SYSZ_INS_LOCHINZ = 1361
SYSZ_INS_LOCHIO = 1362
SYSZ_INS_LOCHIP = 1363
SYSZ_INS_LOCHIZ = 1364
SYSZ_INS_LOCM = 1365
SYSZ_INS_LOCNM = 1366
SYSZ_INS_LOCNP = 1367
SYSZ_INS_LOCNZ = 1368
SYSZ_INS_LOCP = 1369
SYSZ_INS_LOCRM = 1370
SYSZ_INS_LOCRNM = 1371
SYSZ_INS_LOCRNP = 1372
SYSZ_INS_LOCRNZ = 1373
SYSZ_INS_LOCRP = 1374
SYSZ_INS_LOCRZ = 1375
SYSZ_INS_LOCZ = 1376
SYSZ_INS_LPCTL = 1377
SYSZ_INS_LPD = 1378
SYSZ_INS_LPDFR = 1379
SYSZ_INS_LPDG = 1380
SYSZ_INS_LPDR = 1381
SYSZ_INS_LPER = 1382
SYSZ_INS_LPP = 1383
SYSZ_INS_LPQ = 1384
SYSZ_INS_LPSW = 1385
SYSZ_INS_LPSWE = 1386
SYSZ_INS_LPTEA = 1387
SYSZ_INS_LPXR = 1388
SYSZ_INS_LRA = 1389
SYSZ_INS_LRAG = 1390
SYSZ_INS_LRAY = 1391
SYSZ_INS_LRDR = 1392
SYSZ_INS_LRER = 1393
SYSZ_INS_LRVH = 1394
SYSZ_INS_LSCTL = 1395
SYSZ_INS_LTDR = 1396
SYSZ_INS_LTDTR = 1397
SYSZ_INS_LTER = 1398
SYSZ_INS_LTXR = 1399
SYSZ_INS_LTXTR = 1400
SYSZ_INS_LURA = 1401
SYSZ_INS_LURAG = 1402
SYSZ_INS_LXD = 1403
SYSZ_INS_LXDR = 1404
SYSZ_INS_LXDTR = 1405
SYSZ_INS_LXE = 1406
SYSZ_INS_LXER = 1407
SYSZ_INS_LZRF = 1408
SYSZ_INS_LZRG = 1409
SYSZ_INS_M = 1410
SYSZ_INS_MAD = 1411
SYSZ_INS_MADR = 1412
SYSZ_INS_MAE = 1413
SYSZ_INS_MAER = 1414
SYSZ_INS_MAY = 1415
SYSZ_INS_MAYH = 1416
SYSZ_INS_MAYHR = 1417
SYSZ_INS_MAYL = 1418
SYSZ_INS_MAYLR = 1419
SYSZ_INS_MAYR = 1420
SYSZ_INS_MC = 1421
SYSZ_INS_MD = 1422
SYSZ_INS_MDE = 1423
SYSZ_INS_MDER = 1424
SYSZ_INS_MDR = 1425
SYSZ_INS_MDTR = 1426
SYSZ_INS_MDTRA = 1427
SYSZ_INS_ME = 1428
SYSZ_INS_MEE = 1429
SYSZ_INS_MEER = 1430
SYSZ_INS_MER = 1431
SYSZ_INS_MFY = 1432
SYSZ_INS_MG = 1433
SYSZ_INS_MGH = 1434
SYSZ_INS_MGRK = 1435
SYSZ_INS_ML = 1436
SYSZ_INS_MLR = 1437
SYSZ_INS_MP = 1438
SYSZ_INS_MR = 1439
SYSZ_INS_MSC = 1440
SYSZ_INS_MSCH = 1441
SYSZ_INS_MSD = 1442
SYSZ_INS_MSDR = 1443
SYSZ_INS_MSE = 1444
SYSZ_INS_MSER = 1445
SYSZ_INS_MSGC = 1446
SYSZ_INS_MSGRKC = 1447
SYSZ_INS_MSRKC = 1448
SYSZ_INS_MSTA = 1449
SYSZ_INS_MVCDK = 1450
SYSZ_INS_MVCIN = 1451
SYSZ_INS_MVCK = 1452
SYSZ_INS_MVCL = 1453
SYSZ_INS_MVCLE = 1454
SYSZ_INS_MVCLU = 1455
SYSZ_INS_MVCOS = 1456
SYSZ_INS_MVCP = 1457
SYSZ_INS_MVCS = 1458
SYSZ_INS_MVCSK = 1459
SYSZ_INS_MVN = 1460
SYSZ_INS_MVO = 1461
SYSZ_INS_MVPG = 1462
SYSZ_INS_MVZ = 1463
SYSZ_INS_MXD = 1464
SYSZ_INS_MXDR = 1465
SYSZ_INS_MXR = 1466
SYSZ_INS_MXTR = 1467
SYSZ_INS_MXTRA = 1468
SYSZ_INS_MY = 1469
SYSZ_INS_MYH = 1470
SYSZ_INS_MYHR = 1471
SYSZ_INS_MYL = 1472
SYSZ_INS_MYLR = 1473
SYSZ_INS_MYR = 1474
SYSZ_INS_NIAI = 1475
SYSZ_INS_NTSTG = 1476
SYSZ_INS_PACK = 1477
SYSZ_INS_PALB = 1478
SYSZ_INS_PC = 1479
SYSZ_INS_PCC = 1480
SYSZ_INS_PCKMO = 1481
SYSZ_INS_PFMF = 1482
SYSZ_INS_PFPO = 1483
SYSZ_INS_PGIN = 1484
SYSZ_INS_PGOUT = 1485
SYSZ_INS_PKA = 1486
SYSZ_INS_PKU = 1487
SYSZ_INS_PLO = 1488
SYSZ_INS_POPCNT = 1489
SYSZ_INS_PPA = 1490
SYSZ_INS_PPNO = 1491
SYSZ_INS_PR = 1492
SYSZ_INS_PRNO = 1493
SYSZ_INS_PT = 1494
SYSZ_INS_PTF = 1495
SYSZ_INS_PTFF = 1496
SYSZ_INS_PTI = 1497
SYSZ_INS_PTLB = 1498
SYSZ_INS_QADTR = 1499
SYSZ_INS_QAXTR = 1500
SYSZ_INS_QCTRI = 1501
SYSZ_INS_QSI = 1502
SYSZ_INS_RCHP = 1503
SYSZ_INS_RISBGN = 1504
SYSZ_INS_RP = 1505
SYSZ_INS_RRBE = 1506
SYSZ_INS_RRBM = 1507
SYSZ_INS_RRDTR = 1508
SYSZ_INS_RRXTR = 1509
SYSZ_INS_RSCH = 1510
SYSZ_INS_SAC = 1511
SYSZ_INS_SACF = 1512
SYSZ_INS_SAL = 1513
SYSZ_INS_SAM24 = 1514
SYSZ_INS_SAM31 = 1515
SYSZ_INS_SAM64 = 1516
SYSZ_INS_SAR = 1517
SYSZ_INS_SCCTR = 1518
SYSZ_INS_SCHM = 1519
SYSZ_INS_SCK = 1520
SYSZ_INS_SCKC = 1521
SYSZ_INS_SCKPF = 1522
SYSZ_INS_SD = 1523
SYSZ_INS_SDR = 1524
SYSZ_INS_SDTR = 1525
SYSZ_INS_SDTRA = 1526
SYSZ_INS_SE = 1527
SYSZ_INS_SER = 1528
SYSZ_INS_SFASR = 1529
SYSZ_INS_SFPC = 1530
SYSZ_INS_SGH = 1531
SYSZ_INS_SHHHR = 1532
SYSZ_INS_SHHLR = 1533
SYSZ_INS_SIE = 1534
SYSZ_INS_SIGA = 1535
SYSZ_INS_SIGP = 1536
SYSZ_INS_SLA = 1537
SYSZ_INS_SLAG = 1538
SYSZ_INS_SLAK = 1539
SYSZ_INS_SLDA = 1540
SYSZ_INS_SLDL = 1541
SYSZ_INS_SLDT = 1542
SYSZ_INS_SLHHHR = 1543
SYSZ_INS_SLHHLR = 1544
SYSZ_INS_SLXT = 1545
SYSZ_INS_SP = 1546
SYSZ_INS_SPCTR = 1547
SYSZ_INS_SPKA = 1548
SYSZ_INS_SPM = 1549
SYSZ_INS_SPT = 1550
SYSZ_INS_SPX = 1551
SYSZ_INS_SQD = 1552
SYSZ_INS_SQDR = 1553
SYSZ_INS_SQE = 1554
SYSZ_INS_SQER = 1555
SYSZ_INS_SQXR = 1556
SYSZ_INS_SRDA = 1557
SYSZ_INS_SRDL = 1558
SYSZ_INS_SRDT = 1559
SYSZ_INS_SRNM = 1560
SYSZ_INS_SRNMB = 1561
SYSZ_INS_SRNMT = 1562
SYSZ_INS_SRP = 1563
SYSZ_INS_SRSTU = 1564
SYSZ_INS_SRXT = 1565
SYSZ_INS_SSAIR = 1566
SYSZ_INS_SSAR = 1567
SYSZ_INS_SSCH = 1568
SYSZ_INS_SSKE = 1569
SYSZ_INS_SSM = 1570
SYSZ_INS_STAM = 1571
SYSZ_INS_STAMY = 1572
SYSZ_INS_STAP = 1573
SYSZ_INS_STCK = 1574
SYSZ_INS_STCKC = 1575
SYSZ_INS_STCKE = 1576
SYSZ_INS_STCKF = 1577
SYSZ_INS_STCM = 1578
SYSZ_INS_STCMH = 1579
SYSZ_INS_STCMY = 1580
SYSZ_INS_STCPS = 1581
SYSZ_INS_STCRW = 1582
SYSZ_INS_STCTG = 1583
SYSZ_INS_STCTL = 1584
SYSZ_INS_STFL = 1585
SYSZ_INS_STFLE = 1586
SYSZ_INS_STFPC = 1587
SYSZ_INS_STGSC = 1588
SYSZ_INS_STIDP = 1589
SYSZ_INS_STM = 1590
SYSZ_INS_STMH = 1591
SYSZ_INS_STMY = 1592
SYSZ_INS_STNSM = 1593
SYSZ_INS_STOCFH = 1594
SYSZ_INS_STOCFHE = 1595
SYSZ_INS_STOCFHH = 1596
SYSZ_INS_STOCFHHE = 1597
SYSZ_INS_STOCFHL = 1598
SYSZ_INS_STOCFHLE = 1599
SYSZ_INS_STOCFHLH = 1600
SYSZ_INS_STOCFHM = 1601
SYSZ_INS_STOCFHNE = 1602
SYSZ_INS_STOCFHNH = 1603
SYSZ_INS_STOCFHNHE = 1604
SYSZ_INS_STOCFHNL = 1605
SYSZ_INS_STOCFHNLE = 1606
SYSZ_INS_STOCFHNLH = 1607
SYSZ_INS_STOCFHNM = 1608
SYSZ_INS_STOCFHNO = 1609
SYSZ_INS_STOCFHNP = 1610
SYSZ_INS_STOCFHNZ = 1611
SYSZ_INS_STOCFHO = 1612
SYSZ_INS_STOCFHP = 1613
SYSZ_INS_STOCFHZ = 1614
SYSZ_INS_STOCGM = 1615
SYSZ_INS_STOCGNM = 1616
SYSZ_INS_STOCGNP = 1617
SYSZ_INS_STOCGNZ = 1618
SYSZ_INS_STOCGP = 1619
SYSZ_INS_STOCGZ = 1620
SYSZ_INS_STOCM = 1621
SYSZ_INS_STOCNM = 1622
SYSZ_INS_STOCNP = 1623
SYSZ_INS_STOCNZ = 1624
SYSZ_INS_STOCP = 1625
SYSZ_INS_STOCZ = 1626
SYSZ_INS_STOSM = 1627
SYSZ_INS_STPQ = 1628
SYSZ_INS_STPT = 1629
SYSZ_INS_STPX = 1630
SYSZ_INS_STRAG = 1631
SYSZ_INS_STRVH = 1632
SYSZ_INS_STSCH = 1633
SYSZ_INS_STSI = 1634
SYSZ_INS_STURA = 1635
SYSZ_INS_STURG = 1636
SYSZ_INS_SU = 1637
SYSZ_INS_SUR = 1638
SYSZ_INS_SVC = 1639
SYSZ_INS_SW = 1640
SYSZ_INS_SWR = 1641
SYSZ_INS_SXR = 1642
SYSZ_INS_SXTR = 1643
SYSZ_INS_SXTRA = 1644
SYSZ_INS_TABORT = 1645
SYSZ_INS_TAM = 1646
SYSZ_INS_TAR = 1647
SYSZ_INS_TB = 1648
SYSZ_INS_TBDR = 1649
SYSZ_INS_TBEDR = 1650
SYSZ_INS_TBEGIN = 1651
SYSZ_INS_TBEGINC = 1652
SYSZ_INS_TCDB = 1653
SYSZ_INS_TCEB = 1654
SYSZ_INS_TCXB = 1655
SYSZ_INS_TDCDT = 1656
SYSZ_INS_TDCET = 1657
SYSZ_INS_TDCXT = 1658
SYSZ_INS_TDGDT = 1659
SYSZ_INS_TDGET = 1660
SYSZ_INS_TDGXT = 1661
SYSZ_INS_TEND = 1662
SYSZ_INS_THDER = 1663
SYSZ_INS_THDR = 1664
SYSZ_INS_TP = 1665
SYSZ_INS_TPI = 1666
SYSZ_INS_TPROT = 1667
SYSZ_INS_TR = 1668
SYSZ_INS_TRACE = 1669
SYSZ_INS_TRACG = 1670
SYSZ_INS_TRAP2 = 1671
SYSZ_INS_TRAP4 = 1672
SYSZ_INS_TRE = 1673
SYSZ_INS_TROO = 1674
SYSZ_INS_TROT = 1675
SYSZ_INS_TRT = 1676
SYSZ_INS_TRTE = 1677
SYSZ_INS_TRTO = 1678
SYSZ_INS_TRTR = 1679
SYSZ_INS_TRTRE = 1680
SYSZ_INS_TRTT = 1681
SYSZ_INS_TS = 1682
SYSZ_INS_TSCH = 1683
SYSZ_INS_UNPK = 1684
SYSZ_INS_UNPKA = 1685
SYSZ_INS_UNPKU = 1686
SYSZ_INS_UPT = 1687
SYSZ_INS_VA = 1688
SYSZ_INS_VAB = 1689
SYSZ_INS_VAC = 1690
SYSZ_INS_VACC = 1691
SYSZ_INS_VACCB = 1692
SYSZ_INS_VACCC = 1693
SYSZ_INS_VACCCQ = 1694
SYSZ_INS_VACCF = 1695
SYSZ_INS_VACCG = 1696
SYSZ_INS_VACCH = 1697
SYSZ_INS_VACCQ = 1698
SYSZ_INS_VACQ = 1699
SYSZ_INS_VAF = 1700
SYSZ_INS_VAG = 1701
SYSZ_INS_VAH = 1702
SYSZ_INS_VAP = 1703
SYSZ_INS_VAQ = 1704
SYSZ_INS_VAVG = 1705
SYSZ_INS_VAVGB = 1706
SYSZ_INS_VAVGF = 1707
SYSZ_INS_VAVGG = 1708
SYSZ_INS_VAVGH = 1709
SYSZ_INS_VAVGL = 1710
SYSZ_INS_VAVGLB = 1711
SYSZ_INS_VAVGLF = 1712
SYSZ_INS_VAVGLG = 1713
SYSZ_INS_VAVGLH = 1714
SYSZ_INS_VBPERM = 1715
SYSZ_INS_VCDG = 1716
SYSZ_INS_VCDGB = 1717
SYSZ_INS_VCDLG = 1718
SYSZ_INS_VCDLGB = 1719
SYSZ_INS_VCEQ = 1720
SYSZ_INS_VCEQB = 1721
SYSZ_INS_VCEQBS = 1722
SYSZ_INS_VCEQF = 1723
SYSZ_INS_VCEQFS = 1724
SYSZ_INS_VCEQG = 1725
SYSZ_INS_VCEQGS = 1726
SYSZ_INS_VCEQH = 1727
SYSZ_INS_VCEQHS = 1728
SYSZ_INS_VCGD = 1729
SYSZ_INS_VCGDB = 1730
SYSZ_INS_VCH = 1731
SYSZ_INS_VCHB = 1732
SYSZ_INS_VCHBS = 1733
SYSZ_INS_VCHF = 1734
SYSZ_INS_VCHFS = 1735
SYSZ_INS_VCHG = 1736
SYSZ_INS_VCHGS = 1737
SYSZ_INS_VCHH = 1738
SYSZ_INS_VCHHS = 1739
SYSZ_INS_VCHL = 1740
SYSZ_INS_VCHLB = 1741
SYSZ_INS_VCHLBS = 1742
SYSZ_INS_VCHLF = 1743
SYSZ_INS_VCHLFS = 1744
SYSZ_INS_VCHLG = 1745
SYSZ_INS_VCHLGS = 1746
SYSZ_INS_VCHLH = 1747
SYSZ_INS_VCHLHS = 1748
SYSZ_INS_VCKSM = 1749
SYSZ_INS_VCLGD = 1750
SYSZ_INS_VCLGDB = 1751
SYSZ_INS_VCLZ = 1752
SYSZ_INS_VCLZB = 1753
SYSZ_INS_VCLZF = 1754
SYSZ_INS_VCLZG = 1755
SYSZ_INS_VCLZH = 1756
SYSZ_INS_VCP = 1757
SYSZ_INS_VCTZ = 1758
SYSZ_INS_VCTZB = 1759
SYSZ_INS_VCTZF = 1760
SYSZ_INS_VCTZG = 1761
SYSZ_INS_VCTZH = 1762
SYSZ_INS_VCVB = 1763
SYSZ_INS_VCVBG = 1764
SYSZ_INS_VCVD = 1765
SYSZ_INS_VCVDG = 1766
SYSZ_INS_VDP = 1767
SYSZ_INS_VEC = 1768
SYSZ_INS_VECB = 1769
SYSZ_INS_VECF = 1770
SYSZ_INS_VECG = 1771
SYSZ_INS_VECH = 1772
SYSZ_INS_VECL = 1773
SYSZ_INS_VECLB = 1774
SYSZ_INS_VECLF = 1775
SYSZ_INS_VECLG = 1776
SYSZ_INS_VECLH = 1777
SYSZ_INS_VERIM = 1778
SYSZ_INS_VERIMB = 1779
SYSZ_INS_VERIMF = 1780
SYSZ_INS_VERIMG = 1781
SYSZ_INS_VERIMH = 1782
SYSZ_INS_VERLL = 1783
SYSZ_INS_VERLLB = 1784
SYSZ_INS_VERLLF = 1785
SYSZ_INS_VERLLG = 1786
SYSZ_INS_VERLLH = 1787
SYSZ_INS_VERLLV = 1788
SYSZ_INS_VERLLVB = 1789
SYSZ_INS_VERLLVF = 1790
SYSZ_INS_VERLLVG = 1791
SYSZ_INS_VERLLVH = 1792
SYSZ_INS_VESL = 1793
SYSZ_INS_VESLB = 1794
SYSZ_INS_VESLF = 1795
SYSZ_INS_VESLG = 1796
SYSZ_INS_VESLH = 1797
SYSZ_INS_VESLV = 1798
SYSZ_INS_VESLVB = 1799
SYSZ_INS_VESLVF = 1800
SYSZ_INS_VESLVG = 1801
SYSZ_INS_VESLVH = 1802
SYSZ_INS_VESRA = 1803
SYSZ_INS_VESRAB = 1804
SYSZ_INS_VESRAF = 1805
SYSZ_INS_VESRAG = 1806
SYSZ_INS_VESRAH = 1807
SYSZ_INS_VESRAV = 1808
SYSZ_INS_VESRAVB = 1809
SYSZ_INS_VESRAVF = 1810
SYSZ_INS_VESRAVG = 1811
SYSZ_INS_VESRAVH = 1812
SYSZ_INS_VESRL = 1813
SYSZ_INS_VESRLB = 1814
SYSZ_INS_VESRLF = 1815
SYSZ_INS_VESRLG = 1816
SYSZ_INS_VESRLH = 1817
SYSZ_INS_VESRLV = 1818
SYSZ_INS_VESRLVB = 1819
SYSZ_INS_VESRLVF = 1820
SYSZ_INS_VESRLVG = 1821
SYSZ_INS_VESRLVH = 1822
SYSZ_INS_VFA = 1823
SYSZ_INS_VFADB = 1824
SYSZ_INS_VFAE = 1825
SYSZ_INS_VFAEB = 1826
SYSZ_INS_VFAEBS = 1827
SYSZ_INS_VFAEF = 1828
SYSZ_INS_VFAEFS = 1829
SYSZ_INS_VFAEH = 1830
SYSZ_INS_VFAEHS = 1831
SYSZ_INS_VFAEZB = 1832
SYSZ_INS_VFAEZBS = 1833
SYSZ_INS_VFAEZF = 1834
SYSZ_INS_VFAEZFS = 1835
SYSZ_INS_VFAEZH = 1836
SYSZ_INS_VFAEZHS = 1837
SYSZ_INS_VFASB = 1838
SYSZ_INS_VFCE = 1839
SYSZ_INS_VFCEDB = 1840
SYSZ_INS_VFCEDBS = 1841
SYSZ_INS_VFCESB = 1842
SYSZ_INS_VFCESBS = 1843
SYSZ_INS_VFCH = 1844
SYSZ_INS_VFCHDB = 1845
SYSZ_INS_VFCHDBS = 1846
SYSZ_INS_VFCHE = 1847
SYSZ_INS_VFCHEDB = 1848
SYSZ_INS_VFCHEDBS = 1849
SYSZ_INS_VFCHESB = 1850
SYSZ_INS_VFCHESBS = 1851
SYSZ_INS_VFCHSB = 1852
SYSZ_INS_VFCHSBS = 1853
SYSZ_INS_VFD = 1854
SYSZ_INS_VFDDB = 1855
SYSZ_INS_VFDSB = 1856
SYSZ_INS_VFEE = 1857
SYSZ_INS_VFEEB = 1858
SYSZ_INS_VFEEBS = 1859
SYSZ_INS_VFEEF = 1860
SYSZ_INS_VFEEFS = 1861
SYSZ_INS_VFEEH = 1862
SYSZ_INS_VFEEHS = 1863
SYSZ_INS_VFEEZB = 1864
SYSZ_INS_VFEEZBS = 1865
SYSZ_INS_VFEEZF = 1866
SYSZ_INS_VFEEZFS = 1867
SYSZ_INS_VFEEZH = 1868
SYSZ_INS_VFEEZHS = 1869
SYSZ_INS_VFENE = 1870
SYSZ_INS_VFENEB = 1871
SYSZ_INS_VFENEBS = 1872
SYSZ_INS_VFENEF = 1873
SYSZ_INS_VFENEFS = 1874
SYSZ_INS_VFENEH = 1875
SYSZ_INS_VFENEHS = 1876
SYSZ_INS_VFENEZB = 1877
SYSZ_INS_VFENEZBS = 1878
SYSZ_INS_VFENEZF = 1879
SYSZ_INS_VFENEZFS = 1880
SYSZ_INS_VFENEZH = 1881
SYSZ_INS_VFENEZHS = 1882
SYSZ_INS_VFI = 1883
SYSZ_INS_VFIDB = 1884
SYSZ_INS_VFISB = 1885
SYSZ_INS_VFKEDB = 1886
SYSZ_INS_VFKEDBS = 1887
SYSZ_INS_VFKESB = 1888
SYSZ_INS_VFKESBS = 1889
SYSZ_INS_VFKHDB = 1890
SYSZ_INS_VFKHDBS = 1891
SYSZ_INS_VFKHEDB = 1892
SYSZ_INS_VFKHEDBS = 1893
SYSZ_INS_VFKHESB = 1894
SYSZ_INS_VFKHESBS = 1895
SYSZ_INS_VFKHSB = 1896
SYSZ_INS_VFKHSBS = 1897
SYSZ_INS_VFLCDB = 1898
SYSZ_INS_VFLCSB = 1899
SYSZ_INS_VFLL = 1900
SYSZ_INS_VFLLS = 1901
SYSZ_INS_VFLNDB = 1902
SYSZ_INS_VFLNSB = 1903
SYSZ_INS_VFLPDB = 1904
SYSZ_INS_VFLPSB = 1905
SYSZ_INS_VFLR = 1906
SYSZ_INS_VFLRD = 1907
SYSZ_INS_VFM = 1908
SYSZ_INS_VFMA = 1909
SYSZ_INS_VFMADB = 1910
SYSZ_INS_VFMASB = 1911
SYSZ_INS_VFMAX = 1912
SYSZ_INS_VFMAXDB = 1913
SYSZ_INS_VFMAXSB = 1914
SYSZ_INS_VFMDB = 1915
SYSZ_INS_VFMIN = 1916
SYSZ_INS_VFMINDB = 1917
SYSZ_INS_VFMINSB = 1918
SYSZ_INS_VFMS = 1919
SYSZ_INS_VFMSB = 1920
SYSZ_INS_VFMSDB = 1921
SYSZ_INS_VFMSSB = 1922
SYSZ_INS_VFNMA = 1923
SYSZ_INS_VFNMADB = 1924
SYSZ_INS_VFNMASB = 1925
SYSZ_INS_VFNMS = 1926
SYSZ_INS_VFNMSDB = 1927
SYSZ_INS_VFNMSSB = 1928
SYSZ_INS_VFPSO = 1929
SYSZ_INS_VFPSODB = 1930
SYSZ_INS_VFPSOSB = 1931
SYSZ_INS_VFS = 1932
SYSZ_INS_VFSDB = 1933
SYSZ_INS_VFSQ = 1934
SYSZ_INS_VFSQDB = 1935
SYSZ_INS_VFSQSB = 1936
SYSZ_INS_VFSSB = 1937
SYSZ_INS_VFTCI = 1938
SYSZ_INS_VFTCIDB = 1939
SYSZ_INS_VFTCISB = 1940
SYSZ_INS_VGBM = 1941
SYSZ_INS_VGEF = 1942
SYSZ_INS_VGEG = 1943
SYSZ_INS_VGFM = 1944
SYSZ_INS_VGFMA = 1945
SYSZ_INS_VGFMAB = 1946
SYSZ_INS_VGFMAF = 1947
SYSZ_INS_VGFMAG = 1948
SYSZ_INS_VGFMAH = 1949
SYSZ_INS_VGFMB = 1950
SYSZ_INS_VGFMF = 1951
SYSZ_INS_VGFMG = 1952
SYSZ_INS_VGFMH = 1953
SYSZ_INS_VGM = 1954
SYSZ_INS_VGMB = 1955
SYSZ_INS_VGMF = 1956
SYSZ_INS_VGMG = 1957
SYSZ_INS_VGMH = 1958
SYSZ_INS_VISTR = 1959
SYSZ_INS_VISTRB = 1960
SYSZ_INS_VISTRBS = 1961
SYSZ_INS_VISTRF = 1962
SYSZ_INS_VISTRFS = 1963
SYSZ_INS_VISTRH = 1964
SYSZ_INS_VISTRHS = 1965
SYSZ_INS_VL = 1966
SYSZ_INS_VLBB = 1967
SYSZ_INS_VLC = 1968
SYSZ_INS_VLCB = 1969
SYSZ_INS_VLCF = 1970
SYSZ_INS_VLCG = 1971
SYSZ_INS_VLCH = 1972
SYSZ_INS_VLDE = 1973
SYSZ_INS_VLDEB = 1974
SYSZ_INS_VLEB = 1975
SYSZ_INS_VLED = 1976
SYSZ_INS_VLEDB = 1977
SYSZ_INS_VLEF = 1978
SYSZ_INS_VLEG = 1979
SYSZ_INS_VLEH = 1980
SYSZ_INS_VLEIB = 1981
SYSZ_INS_VLEIF = 1982
SYSZ_INS_VLEIG = 1983
SYSZ_INS_VLEIH = 1984
SYSZ_INS_VLGV = 1985
SYSZ_INS_VLGVB = 1986
SYSZ_INS_VLGVF = 1987
SYSZ_INS_VLGVG = 1988
SYSZ_INS_VLGVH = 1989
SYSZ_INS_VLIP = 1990
SYSZ_INS_VLL = 1991
SYSZ_INS_VLLEZ = 1992
SYSZ_INS_VLLEZB = 1993
SYSZ_INS_VLLEZF = 1994
SYSZ_INS_VLLEZG = 1995
SYSZ_INS_VLLEZH = 1996
SYSZ_INS_VLLEZLF = 1997
SYSZ_INS_VLM = 1998
SYSZ_INS_VLP = 1999
SYSZ_INS_VLPB = 2000
SYSZ_INS_VLPF = 2001
SYSZ_INS_VLPG = 2002
SYSZ_INS_VLPH = 2003
SYSZ_INS_VLR = 2004
SYSZ_INS_VLREP = 2005
SYSZ_INS_VLREPB = 2006
SYSZ_INS_VLREPF = 2007
SYSZ_INS_VLREPG = 2008
SYSZ_INS_VLREPH = 2009
SYSZ_INS_VLRL = 2010
SYSZ_INS_VLRLR = 2011
SYSZ_INS_VLVG = 2012
SYSZ_INS_VLVGB = 2013
SYSZ_INS_VLVGF = 2014
SYSZ_INS_VLVGG = 2015
SYSZ_INS_VLVGH = 2016
SYSZ_INS_VLVGP = 2017
SYSZ_INS_VMAE = 2018
SYSZ_INS_VMAEB = 2019
SYSZ_INS_VMAEF = 2020
SYSZ_INS_VMAEH = 2021
SYSZ_INS_VMAH = 2022
SYSZ_INS_VMAHB = 2023
SYSZ_INS_VMAHF = 2024
SYSZ_INS_VMAHH = 2025
SYSZ_INS_VMAL = 2026
SYSZ_INS_VMALB = 2027
SYSZ_INS_VMALE = 2028
SYSZ_INS_VMALEB = 2029
SYSZ_INS_VMALEF = 2030
SYSZ_INS_VMALEH = 2031
SYSZ_INS_VMALF = 2032
SYSZ_INS_VMALH = 2033
SYSZ_INS_VMALHB = 2034
SYSZ_INS_VMALHF = 2035
SYSZ_INS_VMALHH = 2036
SYSZ_INS_VMALHW = 2037
SYSZ_INS_VMALO = 2038
SYSZ_INS_VMALOB = 2039
SYSZ_INS_VMALOF = 2040
SYSZ_INS_VMALOH = 2041
SYSZ_INS_VMAO = 2042
SYSZ_INS_VMAOB = 2043
SYSZ_INS_VMAOF = 2044
SYSZ_INS_VMAOH = 2045
SYSZ_INS_VME = 2046
SYSZ_INS_VMEB = 2047
SYSZ_INS_VMEF = 2048
SYSZ_INS_VMEH = 2049
SYSZ_INS_VMH = 2050
SYSZ_INS_VMHB = 2051
SYSZ_INS_VMHF = 2052
SYSZ_INS_VMHH = 2053
SYSZ_INS_VML = 2054
SYSZ_INS_VMLB = 2055
SYSZ_INS_VMLE = 2056
SYSZ_INS_VMLEB = 2057
SYSZ_INS_VMLEF = 2058
SYSZ_INS_VMLEH = 2059
SYSZ_INS_VMLF = 2060
SYSZ_INS_VMLH = 2061
SYSZ_INS_VMLHB = 2062
SYSZ_INS_VMLHF = 2063
SYSZ_INS_VMLHH = 2064
SYSZ_INS_VMLHW = 2065
SYSZ_INS_VMLO = 2066
SYSZ_INS_VMLOB = 2067
SYSZ_INS_VMLOF = 2068
SYSZ_INS_VMLOH = 2069
SYSZ_INS_VMN = 2070
SYSZ_INS_VMNB = 2071
SYSZ_INS_VMNF = 2072
SYSZ_INS_VMNG = 2073
SYSZ_INS_VMNH = 2074
SYSZ_INS_VMNL = 2075
SYSZ_INS_VMNLB = 2076
SYSZ_INS_VMNLF = 2077
SYSZ_INS_VMNLG = 2078
SYSZ_INS_VMNLH = 2079
SYSZ_INS_VMO = 2080
SYSZ_INS_VMOB = 2081
SYSZ_INS_VMOF = 2082
SYSZ_INS_VMOH = 2083
SYSZ_INS_VMP = 2084
SYSZ_INS_VMRH = 2085
SYSZ_INS_VMRHB = 2086
SYSZ_INS_VMRHF = 2087
SYSZ_INS_VMRHG = 2088
SYSZ_INS_VMRHH = 2089
SYSZ_INS_VMRL = 2090
SYSZ_INS_VMRLB = 2091
SYSZ_INS_VMRLF = 2092
SYSZ_INS_VMRLG = 2093
SYSZ_INS_VMRLH = 2094
SYSZ_INS_VMSL = 2095
SYSZ_INS_VMSLG = 2096
SYSZ_INS_VMSP = 2097
SYSZ_INS_VMX = 2098
SYSZ_INS_VMXB = 2099
SYSZ_INS_VMXF = 2100
SYSZ_INS_VMXG = 2101
SYSZ_INS_VMXH = 2102
SYSZ_INS_VMXL = 2103
SYSZ_INS_VMXLB = 2104
SYSZ_INS_VMXLF = 2105
SYSZ_INS_VMXLG = 2106
SYSZ_INS_VMXLH = 2107
SYSZ_INS_VN = 2108
SYSZ_INS_VNC = 2109
SYSZ_INS_VNN = 2110
SYSZ_INS_VNO = 2111
SYSZ_INS_VNX = 2112
SYSZ_INS_VO = 2113
SYSZ_INS_VOC = 2114
SYSZ_INS_VONE = 2115
SYSZ_INS_VPDI = 2116
SYSZ_INS_VPERM = 2117
SYSZ_INS_VPK = 2118
SYSZ_INS_VPKF = 2119
SYSZ_INS_VPKG = 2120
SYSZ_INS_VPKH = 2121
SYSZ_INS_VPKLS = 2122
SYSZ_INS_VPKLSF = 2123
SYSZ_INS_VPKLSFS = 2124
SYSZ_INS_VPKLSG = 2125
SYSZ_INS_VPKLSGS = 2126
SYSZ_INS_VPKLSH = 2127
SYSZ_INS_VPKLSHS = 2128
SYSZ_INS_VPKS = 2129
SYSZ_INS_VPKSF = 2130
SYSZ_INS_VPKSFS = 2131
SYSZ_INS_VPKSG = 2132
SYSZ_INS_VPKSGS = 2133
SYSZ_INS_VPKSH = 2134
SYSZ_INS_VPKSHS = 2135
SYSZ_INS_VPKZ = 2136
SYSZ_INS_VPOPCT = 2137
SYSZ_INS_VPOPCTB = 2138
SYSZ_INS_VPOPCTF = 2139
SYSZ_INS_VPOPCTG = 2140
SYSZ_INS_VPOPCTH = 2141
SYSZ_INS_VPSOP = 2142
SYSZ_INS_VREP = 2143
SYSZ_INS_VREPB = 2144
SYSZ_INS_VREPF = 2145
SYSZ_INS_VREPG = 2146
SYSZ_INS_VREPH = 2147
SYSZ_INS_VREPI = 2148
SYSZ_INS_VREPIB = 2149
SYSZ_INS_VREPIF = 2150
SYSZ_INS_VREPIG = 2151
SYSZ_INS_VREPIH = 2152
SYSZ_INS_VRP = 2153
SYSZ_INS_VS = 2154
SYSZ_INS_VSB = 2155
SYSZ_INS_VSBCBI = 2156
SYSZ_INS_VSBCBIQ = 2157
SYSZ_INS_VSBI = 2158
SYSZ_INS_VSBIQ = 2159
SYSZ_INS_VSCBI = 2160
SYSZ_INS_VSCBIB = 2161
SYSZ_INS_VSCBIF = 2162
SYSZ_INS_VSCBIG = 2163
SYSZ_INS_VSCBIH = 2164
SYSZ_INS_VSCBIQ = 2165
SYSZ_INS_VSCEF = 2166
SYSZ_INS_VSCEG = 2167
SYSZ_INS_VSDP = 2168
SYSZ_INS_VSEG = 2169
SYSZ_INS_VSEGB = 2170
SYSZ_INS_VSEGF = 2171
SYSZ_INS_VSEGH = 2172
SYSZ_INS_VSEL = 2173
SYSZ_INS_VSF = 2174
SYSZ_INS_VSG = 2175
SYSZ_INS_VSH = 2176
SYSZ_INS_VSL = 2177
SYSZ_INS_VSLB = 2178
SYSZ_INS_VSLDB = 2179
SYSZ_INS_VSP = 2180
SYSZ_INS_VSQ = 2181
SYSZ_INS_VSRA = 2182
SYSZ_INS_VSRAB = 2183
SYSZ_INS_VSRL = 2184
SYSZ_INS_VSRLB = 2185
SYSZ_INS_VSRP = 2186
SYSZ_INS_VST = 2187
SYSZ_INS_VSTEB = 2188
SYSZ_INS_VSTEF = 2189
SYSZ_INS_VSTEG = 2190
SYSZ_INS_VSTEH = 2191
SYSZ_INS_VSTL = 2192
SYSZ_INS_VSTM = 2193
SYSZ_INS_VSTRC = 2194
SYSZ_INS_VSTRCB = 2195
SYSZ_INS_VSTRCBS = 2196
SYSZ_INS_VSTRCF = 2197
SYSZ_INS_VSTRCFS = 2198
SYSZ_INS_VSTRCH = 2199
SYSZ_INS_VSTRCHS = 2200
SYSZ_INS_VSTRCZB = 2201
SYSZ_INS_VSTRCZBS = 2202
SYSZ_INS_VSTRCZF = 2203
SYSZ_INS_VSTRCZFS = 2204
SYSZ_INS_VSTRCZH = 2205
SYSZ_INS_VSTRCZHS = 2206
SYSZ_INS_VSTRL = 2207
SYSZ_INS_VSTRLR = 2208
SYSZ_INS_VSUM = 2209
SYSZ_INS_VSUMB = 2210
SYSZ_INS_VSUMG = 2211
SYSZ_INS_VSUMGF = 2212
SYSZ_INS_VSUMGH = 2213
SYSZ_INS_VSUMH = 2214
SYSZ_INS_VSUMQ = 2215
SYSZ_INS_VSUMQF = 2216
SYSZ_INS_VSUMQG = 2217
SYSZ_INS_VTM = 2218
SYSZ_INS_VTP = 2219
SYSZ_INS_VUPH = 2220
SYSZ_INS_VUPHB = 2221
SYSZ_INS_VUPHF = 2222
SYSZ_INS_VUPHH = 2223
SYSZ_INS_VUPKZ = 2224
SYSZ_INS_VUPL = 2225
SYSZ_INS_VUPLB = 2226
SYSZ_INS_VUPLF = 2227
SYSZ_INS_VUPLH = 2228
SYSZ_INS_VUPLHB = 2229
SYSZ_INS_VUPLHF = 2230
SYSZ_INS_VUPLHH = 2231
SYSZ_INS_VUPLHW = 2232
SYSZ_INS_VUPLL = 2233
SYSZ_INS_VUPLLB = 2234
SYSZ_INS_VUPLLF = 2235
SYSZ_INS_VUPLLH = 2236
SYSZ_INS_VX = 2237
SYSZ_INS_VZERO = 2238
SYSZ_INS_WCDGB = 2239
SYSZ_INS_WCDLGB = 2240
SYSZ_INS_WCGDB = 2241
SYSZ_INS_WCLGDB = 2242
SYSZ_INS_WFADB = 2243
SYSZ_INS_WFASB = 2244
SYSZ_INS_WFAXB = 2245
SYSZ_INS_WFC = 2246
SYSZ_INS_WFCDB = 2247
SYSZ_INS_WFCEDB = 2248
SYSZ_INS_WFCEDBS = 2249
SYSZ_INS_WFCESB = 2250
SYSZ_INS_WFCESBS = 2251
SYSZ_INS_WFCEXB = 2252
SYSZ_INS_WFCEXBS = 2253
SYSZ_INS_WFCHDB = 2254
SYSZ_INS_WFCHDBS = 2255
SYSZ_INS_WFCHEDB = 2256
SYSZ_INS_WFCHEDBS = 2257
SYSZ_INS_WFCHESB = 2258
SYSZ_INS_WFCHESBS = 2259
SYSZ_INS_WFCHEXB = 2260
SYSZ_INS_WFCHEXBS = 2261
SYSZ_INS_WFCHSB = 2262
SYSZ_INS_WFCHSBS = 2263
SYSZ_INS_WFCHXB = 2264
SYSZ_INS_WFCHXBS = 2265
SYSZ_INS_WFCSB = 2266
SYSZ_INS_WFCXB = 2267
SYSZ_INS_WFDDB = 2268
SYSZ_INS_WFDSB = 2269
SYSZ_INS_WFDXB = 2270
SYSZ_INS_WFIDB = 2271
SYSZ_INS_WFISB = 2272
SYSZ_INS_WFIXB = 2273
SYSZ_INS_WFK = 2274
SYSZ_INS_WFKDB = 2275
SYSZ_INS_WFKEDB = 2276
SYSZ_INS_WFKEDBS = 2277
SYSZ_INS_WFKESB = 2278
SYSZ_INS_WFKESBS = 2279
SYSZ_INS_WFKEXB = 2280
SYSZ_INS_WFKEXBS = 2281
SYSZ_INS_WFKHDB = 2282
SYSZ_INS_WFKHDBS = 2283
SYSZ_INS_WFKHEDB = 2284
SYSZ_INS_WFKHEDBS = 2285
SYSZ_INS_WFKHESB = 2286
SYSZ_INS_WFKHESBS = 2287
SYSZ_INS_WFKHEXB = 2288
SYSZ_INS_WFKHEXBS = 2289
SYSZ_INS_WFKHSB = 2290
SYSZ_INS_WFKHSBS = 2291
SYSZ_INS_WFKHXB = 2292
SYSZ_INS_WFKHXBS = 2293
SYSZ_INS_WFKSB = 2294
SYSZ_INS_WFKXB = 2295
SYSZ_INS_WFLCDB = 2296
SYSZ_INS_WFLCSB = 2297
SYSZ_INS_WFLCXB = 2298
SYSZ_INS_WFLLD = 2299
SYSZ_INS_WFLLS = 2300
SYSZ_INS_WFLNDB = 2301
SYSZ_INS_WFLNSB = 2302
SYSZ_INS_WFLNXB = 2303
SYSZ_INS_WFLPDB = 2304
SYSZ_INS_WFLPSB = 2305
SYSZ_INS_WFLPXB = 2306
SYSZ_INS_WFLRD = 2307
SYSZ_INS_WFLRX = 2308
SYSZ_INS_WFMADB = 2309
SYSZ_INS_WFMASB = 2310
SYSZ_INS_WFMAXB = 2311
SYSZ_INS_WFMAXDB = 2312
SYSZ_INS_WFMAXSB = 2313
SYSZ_INS_WFMAXXB = 2314
SYSZ_INS_WFMDB = 2315
SYSZ_INS_WFMINDB = 2316
SYSZ_INS_WFMINSB = 2317
SYSZ_INS_WFMINXB = 2318
SYSZ_INS_WFMSB = 2319
SYSZ_INS_WFMSDB = 2320
SYSZ_INS_WFMSSB = 2321
SYSZ_INS_WFMSXB = 2322
SYSZ_INS_WFMXB = 2323
SYSZ_INS_WFNMADB = 2324
SYSZ_INS_WFNMASB = 2325
SYSZ_INS_WFNMAXB = 2326
SYSZ_INS_WFNMSDB = 2327
SYSZ_INS_WFNMSSB = 2328
SYSZ_INS_WFNMSXB = 2329
SYSZ_INS_WFPSODB = 2330
SYSZ_INS_WFPSOSB = 2331
SYSZ_INS_WFPSOXB = 2332
SYSZ_INS_WFSDB = 2333
SYSZ_INS_WFSQDB = 2334
SYSZ_INS_WFSQSB = 2335
SYSZ_INS_WFSQXB = 2336
SYSZ_INS_WFSSB = 2337
SYSZ_INS_WFSXB = 2338
SYSZ_INS_WFTCIDB = 2339
SYSZ_INS_WFTCISB = 2340
SYSZ_INS_WFTCIXB = 2341
SYSZ_INS_WLDEB = 2342
SYSZ_INS_WLEDB = 2343
SYSZ_INS_XSCH = 2344
SYSZ_INS_ZAP = 2345
SYSZ_INS_ENDING = 2346

SYSZ_GRP_INVALID = 0
SYSZ_GRP_JUMP = 1
SYSZ_GRP_DISTINCTOPS = 128
SYSZ_GRP_FPEXTENSION = 129
SYSZ_GRP_HIGHWORD = 130
SYSZ_GRP_INTERLOCKEDACCESS1 = 131
SYSZ_GRP_LOADSTOREONCOND = 132
SYSZ_GRP_DFPPACKEDCONVERSION = 133
SYSZ_GRP_DFPZONEDCONVERSION = 134
SYSZ_GRP_ENHANCEDDAT2 = 135
SYSZ_GRP_EXECUTIONHINT = 136
SYSZ_GRP_GUARDEDSTORAGE = 137
SYSZ_GRP_INSERTREFERENCEBITSMULTIPLE = 138
SYSZ_GRP_LOADANDTRAP = 139
SYSZ_GRP_LOADANDZERORIGHTMOSTBYTE = 140
SYSZ_GRP_LOADSTOREONCOND2 = 141
SYSZ_GRP_MESSAGESECURITYASSIST3 = 142
SYSZ_GRP_MESSAGESECURITYASSIST4 = 143
SYSZ_GRP_MESSAGESECURITYASSIST5 = 144
SYSZ_GRP_MESSAGESECURITYASSIST7 = 145
SYSZ_GRP_MESSAGESECURITYASSIST8 = 146
SYSZ_GRP_MISCELLANEOUSEXTENSIONS = 147
SYSZ_GRP_MISCELLANEOUSEXTENSIONS2 = 148
SYSZ_GRP_NOVECTOR = 149
SYSZ_GRP_POPULATIONCOUNT = 150
SYSZ_GRP_PROCESSORASSIST = 151
SYSZ_GRP_RESETREFERENCEBITSMULTIPLE = 152
SYSZ_GRP_TRANSACTIONALEXECUTION = 153
SYSZ_GRP_VECTOR = 154
SYSZ_GRP_VECTORENHANCEMENTS1 = 155
SYSZ_GRP_VECTORPACKEDDECIMAL = 156
SYSZ_GRP_ENDING = 157



#!/usr/bin/env python

# Capstone Python bindings, by Sebastian Macke <Sebastian Macke>
from __future__ import print_function
from capstone import *
from capstone.mos65xx import *
from xprint import to_hex, to_x

MOS65XX_CODE = b"\x0d\x34\x12\x00\x81\x65\x6c\x01\x00\x85\xFF\x10\x00\x19\x42\x42\x00\x49\x42"

address_modes=[
    "No address mode",
    "implied",
    "accumulator",
    "immediate value",
    "relative",
    "interrupt signature",
    "block move",
    "zero page",
    "zero page indexed with x",
    "zero page indexed with y",
    "relative bit branch",
    "zero page indirect",
    "zero page indexed with x indirect",
    "zero page indirect indexed with y",
    "zero page indirect long",
    "zero page indirect long indexed with y",
    "absolute",
    "absolute indexed with x",
    "absolute indexed with y",
    "absolute indirect",
    "absolute indexed with x indirect",
    "absolute indirect long",
    "absolute long",
    "absolute long indexed with x",
    "stack relative",
    "stack relative indirect indexed with y",
];


def print_insn_detail(insn):
    # print address, mnemonic and operands
    print("0x%x:\t%s\t%s" % (insn.address, insn.mnemonic, insn.op_str))

    # "data" instruction generated by SKIPDATA option has no detail
    if insn.id == 0:
        return
    print("\taddress mode: %s" % (address_modes[insn.am]))
    print("\tmodifies flags: %s" % ('true' if insn.modifies_flags != 0 else 'false'))
    if len(insn.operands) > 0:
        print("\top_count: %u" % len(insn.operands))
        c = -1
        for i in insn.operands:
            c += 1
            if i.type == MOS65XX_OP_REG:
                print("\t\toperands[%u].type: REG = %s" % (c, insn.reg_name(i.reg)))
            if i.type == MOS65XX_OP_IMM:
                print("\t\toperands[%u].type: IMM = 0x%s" % (c, to_x(i.imm)))
            if i.type == MOS65XX_OP_MEM:
                print("\t\toperands[%u].type: MEM = 0x%s" % (c, to_x(i.mem)))


# ## Test class Cs
def test_class():
    print("*" * 16)
    print("Platform: %s" % "MOS65XX")
    print("Code: %s" % to_hex(MOS65XX_CODE))
    print("Disasm:")

    try:
        md = Cs(CS_ARCH_MOS65XX, 0)
        md.detail = True
        for insn in md.disasm(MOS65XX_CODE, 0x1000):
            print_insn_detail(insn)
            print()

        print("0x%x:\n" % (insn.address + insn.size))
    except CsError as e:
        print("ERROR: %s" % e)


if __name__ == '__main__':
    test_class()



#!/usr/bin/python
# print list of instructions LLVM inc files, for Capstone disassembler.
# this will be put into capstone/<arch>.h
# by Nguyen Anh Quynh, 2019

import sys

if len(sys.argv) == 1:
    print("Syntax: %s <GenAsmMatcher.inc>" %sys.argv[0])
    sys.exit(1)

print("""/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* This is auto-gen data for Capstone disassembly engine (www.capstone-engine.org) */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */
""")

# lib/Target/X86/X86GenAsmMatcher.inc
# static const MatchEntry MatchTable1[] = {
#  { 0 /* aaa */, X86::AAA, Convert_NoOperands, Feature_Not64BitMode, {  }, },

# extract insn from GenAsmMatcher Table
# return (arch, mnem, insn_id)
def extract_insn(line):
    tmp = line.split(',')
    insn_raw = tmp[1].strip()
    insn_mnem = tmp[0].split(' ')[3]
    # X86 mov.s
    if '.' in insn_mnem:
        tmp = insn_mnem.split('.')
        insn_mnem = tmp[0]
    tmp = insn_raw.split('::')
    arch = tmp[0]
    # AArch64 -> ARM64
    if arch.upper() == 'AARCH64':
        arch = 'ARM64'
    return (arch, insn_mnem, tmp[1])



# extract all insn lines from GenAsmMatcher
# return arch, first_insn, insn_id_list
def extract_matcher(filename):
    f = open(filename)
    lines = f.readlines()
    f.close()

    match_count = 0
    mnem_list = []
    insn_id_list = {}
    arch = None
    first_insn = None

    pattern = None
    # first we try to find Table1, or Table0
    for line in lines:
        if 'MatchEntry MatchTable0[] = {' in line.strip():
            pattern = 'MatchEntry MatchTable0[] = {'
        elif 'MatchEntry MatchTable1[] = {' in line.strip():
            pattern = 'MatchEntry MatchTable1[] = {'
            # last pattern, done
            break

    # 1st enum is register enum
    for line in lines:
        line = line.rstrip()
    
        if len(line.strip()) == 0:
            continue
    
        if pattern in line.strip():
            match_count += 1
            #print(line.strip())
            continue
    
        line = line.strip()
        if match_count == 1:
            if line == '};':
                # done with first enum
                break
            else:
                _arch, mnem, insn_id = extract_insn(line)
                # skip pseudo instructions
                if not mnem.startswith('__'):
                    # PPC
                    if mnem.endswith('-') or mnem.endswith('+'):
                        mnem = mnem[:-1]

                    if not first_insn:
                        arch, first_insn = _arch, insn_id

                    if not insn_id in insn_id_list:
                        # save this
                        insn_id_list[insn_id] = mnem

                    if not mnem in mnem_list:
                        print('\t"%s", // %s_INS_%s,' %(mnem.lower(), arch, mnem.upper()))
                        mnem_list.append(mnem)

    #return arch, first_insn, insn_id_list
    return arch, first_insn, insn_id_list

# GenAsmMatcher.inc
#arch, first_insn, insn_id_list, match_lines = extract_matcher(sys.argv[1])
arch, first_insn, insn_id_list = extract_matcher(sys.argv[1])



# Capstone Python bindings, by Nguyen Anh Quynnh <aquynh@gmail.com>

import ctypes
from . import copy_ctypes_list
from .x86_const import *

# define the API
class X86OpMem(ctypes.Structure):
    _fields_ = (
        ('segment', ctypes.c_uint),
        ('base', ctypes.c_uint),
        ('index', ctypes.c_uint),
        ('scale', ctypes.c_int),
        ('disp', ctypes.c_int64),
    )

class X86OpValue(ctypes.Union):
    _fields_ = (
        ('reg', ctypes.c_uint),
        ('imm', ctypes.c_int64),
        ('mem', X86OpMem),
    )

class X86Op(ctypes.Structure):
    _fields_ = (
        ('type', ctypes.c_uint),
        ('value', X86OpValue),
        ('size', ctypes.c_uint8),
        ('access', ctypes.c_uint8),
        ('avx_bcast', ctypes.c_uint),
        ('avx_zero_opmask', ctypes.c_bool),
    )

    @property
    def imm(self):
        return self.value.imm

    @property
    def reg(self):
        return self.value.reg

    @property
    def mem(self):
        return self.value.mem

class X86Flags(ctypes.Union):
    _fields_ = (
        ('eflags', ctypes.c_uint64),
        ('fpu_flags', ctypes.c_uint64),
    )

class CsX86Encoding(ctypes.Structure):
    _fields_ = (
        ('modrm_offset', ctypes.c_uint8),
        ('disp_offset', ctypes.c_uint8),
        ('disp_size', ctypes.c_uint8),
        ('imm_offset', ctypes.c_uint8),
        ('imm_size', ctypes.c_uint8),
    )

class CsX86(ctypes.Structure):
    _fields_ = (
        ('prefix', ctypes.c_uint8 * 4),
        ('opcode', ctypes.c_uint8 * 4),
        ('rex', ctypes.c_uint8),
        ('addr_size', ctypes.c_uint8),
        ('modrm', ctypes.c_uint8),
        ('sib', ctypes.c_uint8),
        ('disp', ctypes.c_int64),
        ('sib_index', ctypes.c_uint),
        ('sib_scale', ctypes.c_int8),
        ('sib_base', ctypes.c_uint),
        ('xop_cc', ctypes.c_uint),
        ('sse_cc', ctypes.c_uint),
        ('avx_cc', ctypes.c_uint),
        ('avx_sae', ctypes.c_bool),
        ('avx_rm', ctypes.c_uint),
        ('flags', X86Flags),
        ('op_count', ctypes.c_uint8),
        ('operands', X86Op * 8),
        ('encoding', CsX86Encoding),
    )

    @property
    def eflags(self):
        return self.flags.eflags
    
    @property
    def fpu_flags(self):
        return self.flags.fpu_flags

def get_arch_info(a):
    return (a.prefix[:], a.opcode[:], a.rex, a.addr_size, \
            a.modrm, a.sib, a.disp, a.sib_index, a.sib_scale, \
            a.sib_base, a.xop_cc, a.sse_cc, a.avx_cc, a.avx_sae, a.avx_rm, a.eflags, a.fpu_flags, \
            a.encoding, a.encoding.modrm_offset, a.encoding.disp_offset, a.encoding.disp_size, a.encoding.imm_offset, a.encoding.imm_size, \
            copy_ctypes_list(a.operands[:a.op_count]))




#!/usr/bin/env python

# Capstone Python bindings, by Nguyen Anh Quynnh <aquynh@gmail.com>
from __future__ import print_function
from capstone import *
from capstone.mips import *
from xprint import to_hex, to_x


MIPS_CODE = b"\x0C\x10\x00\x97\x00\x00\x00\x00\x24\x02\x00\x0c\x8f\xa2\x00\x00\x34\x21\x34\x56"
MIPS_CODE2 = b"\x56\x34\x21\x34\xc2\x17\x01\x00"
MIPS_32R6M = b"\x00\x07\x00\x07\x00\x11\x93\x7c\x01\x8c\x8b\x7c\x00\xc7\x48\xd0"
MIPS_32R6 = b"\xec\x80\x00\x19\x7c\x43\x22\xa0"

all_tests = (
        (CS_ARCH_MIPS, CS_MODE_MIPS32 + CS_MODE_BIG_ENDIAN, MIPS_CODE, "MIPS-32 (Big-endian)"),
        (CS_ARCH_MIPS, CS_MODE_MIPS64 + CS_MODE_LITTLE_ENDIAN, MIPS_CODE2, "MIPS-64-EL (Little-endian)"),
        (CS_ARCH_MIPS, CS_MODE_MIPS32R6 + CS_MODE_MICRO + CS_MODE_BIG_ENDIAN, MIPS_32R6M, "MIPS-32R6 | Micro (Big-endian)"),
        (CS_ARCH_MIPS, CS_MODE_MIPS32R6 + CS_MODE_BIG_ENDIAN, MIPS_32R6, "MIPS-32R6 (Big-endian)"),
)


def print_insn_detail(insn):
    # print address, mnemonic and operands
    print("0x%x:\t%s\t%s" % (insn.address, insn.mnemonic, insn.op_str))

    # "data" instruction generated by SKIPDATA option has no detail
    if insn.id == 0:
        return

    if len(insn.operands) > 0:
        print("\top_count: %u" % len(insn.operands))
        c = -1
        for i in insn.operands:
            c += 1
            if i.type == MIPS_OP_REG:
                print("\t\toperands[%u].type: REG = %s" % (c, insn.reg_name(i.reg)))
            if i.type == MIPS_OP_IMM:
                print("\t\toperands[%u].type: IMM = 0x%s" % (c, to_x(i.imm)))
            if i.type == MIPS_OP_MEM:
                print("\t\toperands[%u].type: MEM" % c)
                if i.mem.base != 0:
                    print("\t\t\toperands[%u].mem.base: REG = %s" \
                        % (c, insn.reg_name(i.mem.base)))
                if i.mem.disp != 0:
                    print("\t\t\toperands[%u].mem.disp: 0x%s" \
                        % (c, to_x(i.mem.disp)))


# ## Test class Cs
def test_class():
    for (arch, mode, code, comment) in all_tests:
        print("*" * 16)
        print("Platform: %s" % comment)
        print("Code: %s" % to_hex(code))
        print("Disasm:")

        try:
            md = Cs(arch, mode)
            md.detail = True
            for insn in md.disasm(code, 0x1000):
                print_insn_detail(insn)
                print()

            print("0x%x:\n" % (insn.address + insn.size))
        except CsError as e:
            print("ERROR: %s" % e)


if __name__ == '__main__':
    test_class()



#!/usr/bin/env python

# Capstone Python bindings, by Nguyen Anh Quynnh <aquynh@gmail.com>
from __future__ import print_function
from capstone import *
from xprint import to_hex


X86_CODE16 = b"\x8d\x4c\x32\x08\x01\xd8\x81\xc6\x34\x12\x00\x00"
X86_CODE32 = b"\xba\xcd\xab\x00\x00\x8d\x4c\x32\x08\x01\xd8\x81\xc6\x34\x12\x00\x00"
X86_CODE64 = b"\x55\x48\x8b\x05\xb8\x13\x00\x00"
ARM_CODE = b"\xED\xFF\xFF\xEB\x04\xe0\x2d\xe5\x00\x00\x00\x00\xe0\x83\x22\xe5\xf1\x02\x03\x0e\x00\x00\xa0\xe3\x02\x30\xc1\xe7\x00\x00\x53\xe3"
ARM_CODE2 = b"\x10\xf1\x10\xe7\x11\xf2\x31\xe7\xdc\xa1\x2e\xf3\xe8\x4e\x62\xf3"
THUMB_CODE = b"\x70\x47\xeb\x46\x83\xb0\xc9\x68"
THUMB_CODE2 = b"\x4f\xf0\x00\x01\xbd\xe8\x00\x88\xd1\xe8\x00\xf0"
THUMB_MCLASS = b"\xef\xf3\x02\x80"
ARMV8 = b"\xe0\x3b\xb2\xee\x42\x00\x01\xe1\x51\xf0\x7f\xf5"
MIPS_CODE = b"\x0C\x10\x00\x97\x00\x00\x00\x00\x24\x02\x00\x0c\x8f\xa2\x00\x00\x34\x21\x34\x56"
MIPS_CODE2 = b"\x56\x34\x21\x34\xc2\x17\x01\x00"
MIPS_32R6M = b"\x00\x07\x00\x07\x00\x11\x93\x7c\x01\x8c\x8b\x7c\x00\xc7\x48\xd0"
MIPS_32R6 = b"\xec\x80\x00\x19\x7c\x43\x22\xa0"
ARM64_CODE = b"\x21\x7c\x02\x9b\x21\x7c\x00\x53\x00\x40\x21\x4b\xe1\x0b\x40\xb9"
PPC_CODE = b"\x80\x20\x00\x00\x80\x3f\x00\x00\x10\x43\x23\x0e\xd0\x44\x00\x80\x4c\x43\x22\x02\x2d\x03\x00\x80\x7c\x43\x20\x14\x7c\x43\x20\x93\x4f\x20\x00\x21\x4c\xc8\x00\x21"
PPC_CODE2 = b"\x10\x60\x2a\x10\x10\x64\x28\x88\x7c\x4a\x5d\x0f"
SPARC_CODE = b"\x80\xa0\x40\x02\x85\xc2\x60\x08\x85\xe8\x20\x01\x81\xe8\x00\x00\x90\x10\x20\x01\xd5\xf6\x10\x16\x21\x00\x00\x0a\x86\x00\x40\x02\x01\x00\x00\x00\x12\xbf\xff\xff\x10\xbf\xff\xff\xa0\x02\x00\x09\x0d\xbf\xff\xff\xd4\x20\x60\x00\xd4\x4e\x00\x16\x2a\xc2\x80\x03"
SPARCV9_CODE = b"\x81\xa8\x0a\x24\x89\xa0\x10\x20\x89\xa0\x1a\x60\x89\xa0\x00\xe0"
SYSZ_CODE = b"\xed\x00\x00\x00\x00\x1a\x5a\x0f\x1f\xff\xc2\x09\x80\x00\x00\x00\x07\xf7\xeb\x2a\xff\xff\x7f\x57\xe3\x01\xff\xff\x7f\x57\xeb\x00\xf0\x00\x00\x24\xb2\x4f\x00\x78"
XCORE_CODE = b"\xfe\x0f\xfe\x17\x13\x17\xc6\xfe\xec\x17\x97\xf8\xec\x4f\x1f\xfd\xec\x37\x07\xf2\x45\x5b\xf9\xfa\x02\x06\x1b\x10"
M68K_CODE = b"\xd4\x40\x87\x5a\x4e\x71\x02\xb4\xc0\xde\xc0\xde\x5c\x00\x1d\x80\x71\x12\x01\x23\xf2\x3c\x44\x22\x40\x49\x0e\x56\x54\xc5\xf2\x3c\x44\x00\x44\x7a\x00\x00\xf2\x00\x0a\x28\x4E\xB9\x00\x00\x00\x12\x4E\x75"
M680X_CODE = b"\x06\x10\x19\x1a\x55\x1e\x01\x23\xe9\x31\x06\x34\x55\xa6\x81\xa7\x89\x7f\xff\xa6\x9d\x10\x00\xa7\x91\xa6\x9f\x10\x00\x11\xac\x99\x10\x00\x39"

all_tests = (
        (CS_ARCH_X86, CS_MODE_16, X86_CODE16, "X86 16bit (Intel syntax)", None),
        (CS_ARCH_X86, CS_MODE_32, X86_CODE32, "X86 32bit (ATT syntax)", CS_OPT_SYNTAX_ATT),
        (CS_ARCH_X86, CS_MODE_32, X86_CODE32, "X86 32 (Intel syntax)", None),
        (CS_ARCH_X86, CS_MODE_32, X86_CODE32, "X86 32 (MASM syntax)", CS_OPT_SYNTAX_MASM),
        (CS_ARCH_X86, CS_MODE_64, X86_CODE64, "X86 64 (Intel syntax)", None),
        (CS_ARCH_ARM, CS_MODE_ARM, ARM_CODE, "ARM", None),
        (CS_ARCH_ARM, CS_MODE_THUMB, THUMB_CODE2, "THUMB-2", None),
        (CS_ARCH_ARM, CS_MODE_ARM, ARM_CODE2, "ARM: Cortex-A15 + NEON", None),
        (CS_ARCH_ARM, CS_MODE_THUMB, THUMB_CODE, "THUMB", None),
        (CS_ARCH_ARM, CS_MODE_THUMB + CS_MODE_MCLASS, THUMB_MCLASS, "Thumb-MClass", None),
        (CS_ARCH_ARM, CS_MODE_ARM + CS_MODE_V8, ARMV8, "Arm-V8", None),
        (CS_ARCH_MIPS, CS_MODE_MIPS32 + CS_MODE_BIG_ENDIAN, MIPS_CODE, "MIPS-32 (Big-endian)", None),
        (CS_ARCH_MIPS, CS_MODE_MIPS64 + CS_MODE_LITTLE_ENDIAN, MIPS_CODE2, "MIPS-64-EL (Little-endian)", None),
        (CS_ARCH_MIPS, CS_MODE_MIPS32R6 + CS_MODE_MICRO + CS_MODE_BIG_ENDIAN, MIPS_32R6M, "MIPS-32R6 | Micro (Big-endian)", None),
        (CS_ARCH_MIPS, CS_MODE_MIPS32R6 + CS_MODE_BIG_ENDIAN, MIPS_32R6, "MIPS-32R6 (Big-endian)", None),
        (CS_ARCH_ARM64, CS_MODE_ARM, ARM64_CODE, "ARM-64", None),
        (CS_ARCH_PPC, CS_MODE_BIG_ENDIAN, PPC_CODE, "PPC-64", None),
        (CS_ARCH_PPC, CS_MODE_BIG_ENDIAN, PPC_CODE, "PPC-64, print register with number only", CS_OPT_SYNTAX_NOREGNAME),
        (CS_ARCH_PPC, CS_MODE_BIG_ENDIAN + CS_MODE_QPX, PPC_CODE2, "PPC-64 + QPX", CS_OPT_SYNTAX_NOREGNAME),
        (CS_ARCH_SPARC, CS_MODE_BIG_ENDIAN, SPARC_CODE, "Sparc", None),
        (CS_ARCH_SPARC, CS_MODE_BIG_ENDIAN + CS_MODE_V9, SPARCV9_CODE, "SparcV9", None),
        (CS_ARCH_SYSZ, 0, SYSZ_CODE, "SystemZ", None),
        (CS_ARCH_XCORE, 0, XCORE_CODE, "XCore", None),
        (CS_ARCH_M68K, CS_MODE_BIG_ENDIAN | CS_MODE_M68K_040, M68K_CODE, "M68K (68040)", None),
        (CS_ARCH_M680X, CS_MODE_M680X_6809, M680X_CODE, "M680X_M6809", None),
        )


# ## Test cs_disasm_quick()
def test_cs_disasm_quick():
    for (arch, mode, code, comment, syntax) in all_tests:
        print('*' * 40)
        print("Platform: %s" % comment)
        print("Disasm:"),
        print(to_hex(code))
        for (addr, size, mnemonic, op_str) in cs_disasm_lite(arch, mode, code, 0x1000):
            print("0x%x:\t%s\t%s" % (addr, mnemonic, op_str))
        print()


# ## Test class Cs
def test_class():
    for (arch, mode, code, comment, syntax) in all_tests:
        print('*' * 16)
        print("Platform: %s" % comment)
        print("Code: %s" % to_hex(code))
        print("Disasm:")

        try:
            md = Cs(arch, mode)

            if syntax is not None:
                md.syntax = syntax

            for (addr, size, mnemonic, op_str) in md.disasm_lite(code, 0x1000):
                print("0x%x:\t%s\t%s" % (addr, mnemonic, op_str))

            print("0x%x:" % (addr + size))
            print()
        except CsError as e:
            print("ERROR: %s" % e)


# test_cs_disasm_quick()
# print "*" * 40
if __name__ == '__main__':
    test_class()



#!/usr/bin/python

import re
import sys
import getopt
from subprocess import Popen, PIPE
from pprint import pprint as ppr
import os

_python3 = sys.version_info.major == 3


def Usage(s):
	print('Usage: {} -t <cstest_path> [-f <file_name.cs>] [-d <directory>]'.format(s))
	sys.exit(-1)

def get_report_file(toolpath, filepath, getDetails, cmt_out):
	cmd = [toolpath, '-f', filepath]
	process = Popen(cmd, stdout=PIPE, stderr=PIPE)
	stdout, stderr = process.communicate()

#	stdout
	failed_tests = []
	if _python3:
		stdout = bytes.decode(stdout)
		stderr = bytes.decode(stderr)
	# print('---> stdout\n', stdout)
	# print('---> stderr\n', stderr)
	matches = re.finditer(r'\[\s+RUN\s+\]\s+(.*)\n\[\s+FAILED\s+\]', stdout)
	for match in matches:
		failed_tests.append(match.group(1))
#	stderr
	counter = 0
	details = []
	for line in stderr.split('\n'):
		if '[  PASSED  ] 0 test(s).' in line:
			break
		elif 'LINE' in line:
			continue
		elif 'ERROR' in line and ' --- ' in line:
			parts = line.split(' --- ')
			try:
				details.append((parts[1], failed_tests[counter], parts[2]))
			except IndexError:
				details.append(('', 'Unknown test', line.split(' --- ')[1]))
			counter += 1
		else:
			continue
	print('\n[-] There are/is {} failed test(s)'.format(len(details)))
	if len(details) > 0 and getDetails:
		print('[-] Detailed report for {}:\n'.format(filepath))
		for c, f, d in details:
			print('\t[+] {}: {}\n\t\t{}\n'.format(f, c, d))
		print('\n')
		return 0
	elif len(details) > 0:
		for c, f, d in details:
			if len(f) > 0 and cmt_out is True:
				tmp_cmd = ['sed', '-E', '-i.bak', 's/({})(.*)/\/\/ \\1\\2/g'.format(c), filepath]
				sed_proc = Popen(tmp_cmd, stdout=PIPE, stderr=PIPE)
				sed_proc.communicate()
				tmp_cmd2 = ['rm', '-f', filepath + '.bak']
				rm_proc = Popen(tmp_cmd2, stdout=PIPE, stderr=PIPE)
				rm_proc.communicate()

		return 0
	return 1

def get_report_folder(toolpath, folderpath, details, cmt_out):
	result = 1
	for root, dirs, files in os.walk(folderpath):
		path = root.split(os.sep)
		for f in files:
			if f.split('.')[-1] == 'cs':
				print('[-] Target:', f,)
				result *= get_report_file(toolpath, os.sep.join(x for x in path) + os.sep + f, details, cmt_out)
	
	sys.exit(result ^ 1)

if __name__ == '__main__':
	Done = False
	details = False
	toolpath = ''
	cmt_out = False
	try:
		opts, args = getopt.getopt(sys.argv[1:], "ct:f:d:D")
		for opt, arg in opts:
			if opt == '-f':
				result = get_report_file(toolpath, arg, details, cmt_out)
				if result == 0:
					sys.exit(1)
				Done = True
			elif opt == '-d':
				get_report_folder(toolpath, arg, details, cmt_out)
				Done = True
			elif opt == '-t':
				toolpath = arg
			elif opt == '-D':
				details = True
			elif opt == '-c':
				cmt_out = True

	except getopt.GetoptError:
		Usage(sys.argv[0])

	if Done is False:
		Usage(sys.argv[0])



#!/usr/bin/env python

# Capstone Python bindings, by Nguyen Anh Quynnh <aquynh@gmail.com>
from __future__ import print_function
import sys
from capstone import *

CODE32  = b"\xc0\xe0\x02"
CODE32 += b"\xc0\xf6\x02"              # sal dh, 0
CODE32 += b"\xc1\xf6\x00"              # sal esi, 0
CODE32 += b"\x82\xc0\x00"
CODE32 += b"\x0f\x1a\x00"              # nop dword ptr [eax]
CODE32 += b"\xf7\xc0\x11\x22\x33\x44"  # test eax, 0x44332211
CODE32 += b"\xf7\xc8\x11\x22\x33\x44"  # test eax, 0x44332211
CODE32 += b"\xf7\x88\x00\x00\x00\x00\x00\x00\x00\x00"  # test dword ptr [eax], 0
CODE32 += b"\xf6\x88\x00\x00\x00\x00\x00"              # test byte ptr [eax], 0

CODE32 += b"\xd9\xd8"       # fstpnce st(0), st(0)
CODE32 += b"\xdf\xdf"       # fstp    st(7), st(0)

CODE32 += b"\x0f\x20\x00"       # mov eax, cr0
CODE32 += b"\x0f\x20\x40"       # mov eax, cr0
CODE32 += b"\x0f\x20\x80"       # mov eax, cr0

CODE32 += b"\x0f\x22\x00"       # mov cr0, eax
CODE32 += b"\x0f\x22\x40"       # mov cr0, eax
CODE32 += b"\x0f\x22\x80"       # mov cr0, eax

CODE32 += b"\x0f\x21\x00"       # mov eax, dr0
CODE32 += b"\x0f\x21\x40"       # mov eax, dr0
CODE32 += b"\x0f\x21\x80"       # mov eax, dr0

CODE32 += b"\x0f\x23\x00"       # mov dr0, eax
CODE32 += b"\x0f\x23\x40"       # mov dr0, eax
CODE32 += b"\x0f\x23\x80"       # mov dr0, eax

CODE32 += b"\x66\x2e\x0f\x58\xc0" # addpd   xmm0, xmm0
CODE32 += b"\x2e\x66\x0f\x58\xc0" # addpd   xmm0, xmm0
CODE32 += b"\x66\xf2\x0f\x38\xf1\xc3" # crc32w %bx, %eax
CODE32 += b"\xf2\x0f\x38\xf1\x8c\xcb\xef\xbe\xad\xde" # crc32l -0x21524111(%ebx, %ecx, 8), %ecx

CODE32_MEMREF  = b"\x8b\x84\x91\x23\x01\x00\x00"
CODE32_MEMREF += b"\x8b\x04\x95\x23\x01\x00\x00"
CODE32_MEMREF += b"\x8b\x04\x95\xdd\xfe\xff\xff"
CODE32_MEMREF += b"\xa1\x23\x01\x00\x00"
CODE32_MEMREF += b"\xa1\x00\x00\x00\x00"
CODE32_MEMREF += b"\xa1\xdd\xfe\xff\xff"
CODE32_MEMREF += b"\x8b\x04\x91"

CODE64_MEMREF  = b"\xa3\x0b\x00\x00\x0f\xbe\xc0\x48\x83"
CODE64_MEMREF += b"\xa0\x71\xfa\xff\x48\x85\xc0\x48\x89"

CODE32_ARITH  = b"\x83\xe0\xf7"
CODE32_ARITH += b"\x83\xe0\x10"
CODE32_ARITH += b"\x83\xe0\x00"
CODE32_ARITH += b"\x80\x23\x10"

CODE64_ARITH  = b"\x41\x83\xe0\xfa"
CODE64_ARITH += b"\x48\x83\xe4\xf0"

CODE32_IMM  = b"\xc2\xb8\xc0"
CODE32_IMM += b"\xc2\x0f\x92"
CODE32_IMM += b"\x02\x2d\x00\x00\x00\x83"



_python3 = sys.version_info.major == 3

all_tests = (
        (CS_ARCH_X86, CS_MODE_32, CODE32, "X86 32 (Intel syntax)", 0),
        (CS_ARCH_X86, CS_MODE_32, CODE32, "X86 32 (ATT syntax)", CS_OPT_SYNTAX_ATT),

        (CS_ARCH_X86, CS_MODE_32, CODE32_MEMREF, "X86 32 MemRef (Intel syntax)", 0),
        (CS_ARCH_X86, CS_MODE_32, CODE32_MEMREF, "X86 32 MemRef (ATT syntax)", CS_OPT_SYNTAX_ATT),
        (CS_ARCH_X86, CS_MODE_64, CODE64_MEMREF, "X86 64 (Intel syntax)", 0),

        (CS_ARCH_X86, CS_MODE_32, CODE32_ARITH, "X86 32 (Intel syntax)", 0),
        (CS_ARCH_X86, CS_MODE_64, CODE64_ARITH, "X86 64 (Intel syntax)", 0),

        (CS_ARCH_X86, CS_MODE_32, CODE32_IMM, "X86 32 (Intel syntax)", 0),
        (CS_ARCH_X86, CS_MODE_32, CODE32_IMM, "X86 32 (Intel syntax)", CS_OPT_SYNTAX_ATT),
)


def to_hex(s):
    if _python3:
        return " ".join("0x{0:02x}".format(c) for c in s)  # <-- Python 3 is OK
    else:
        return " ".join("0x{0:02x}".format(ord(c)) for c in s)

# ## Test cs_disasm_quick()
def test_cs_disasm_quick():
    for (arch, mode, code, comment, syntax) in all_tests:
        print("Platform: %s" % comment)
        print("Code: %s" %(to_hex(code))),
        print("Disasm:")
        md = Cs(arch, mode)
        if syntax != 0:
            md.syntax = syntax
        for insn in md.disasm(code, 0x1000):
            print("0x%x:\t%s\t%s" % (insn.address, insn.mnemonic, insn.op_str))
        print("--------")


if __name__ == '__main__':
    test_cs_disasm_quick()
